/******************************************************************************/
/*	PDB Dreamer version 1.02					      */
/*      (A.G. de Brevern - EBGM - U726 INSERM)				      */
/******************************************************************************/
/*	lib_structure.h	(beta version 2005)				      */
/*	---------------							      */
/*	mainly the structure definition of PDB molecule		              */
/*	last modification : 28-05-2005					      */
/******************************************************************************/

# include "lib_define.h"

struct dist{
	char typeatom;
	long numberatom;
	double distanceatom;
	double t_liaison;		/* type de liaison (simple,double,triple,demi,...)*/
	};

/**********************/
/* TURN in PDB file : */
/**********************/

struct turnpos{
	char chain;
	long begin_turn;
	char begin_turn_res;
	long end_turn;
	char end_turn_res;
	short int type_turn;
	};
 
struct turn{
	int nb_turn;
	struct turnpos pdbturnpos[NB_MAX_helix];
	};

/************************/
/* SHEET in PDB file : */
/************************/

struct betapos{
	char chain;
	long begin_beta;
	char begin_beta_res;
	long end_beta;
	char end_beta_res;
	short int type_beta;
	};

struct beta{
	int nb_beta;
	struct betapos pdbbetapos[NB_MAX_helix];
	};

/***********************/
/* HELIX in PDB file : */
/***********************/

struct helixpos{
	char chain;
	long begin_helix;
	char begin_helix_res;
	long end_helix;
	char end_helix_res;
	short int type_helix;
	};

struct helix{
	int nb_helix;
	struct helixpos pdbhelixpos[NB_MAX_helix];
	};

/************************/
/* SEQRES in PDB file : */
/*********-**************/

struct seqres{
	char RESIDUE;
	char local_chain;
	long chain_length;
	};
	
struct seqreschain{
	long nb_res;
	int nb_chain;
	long length_chain[NB_MAX_CHAIN];
	long begin_chain[NB_MAX_CHAIN];
	long end_chain[NB_MAX_CHAIN];
	char name_chain[NB_MAX_CHAIN];
	};
	
	
	/****************************************/
	/* structure des atomes proprement dits */
	/****************************************/
	
struct atomtype
	{
					/* 1-4 ATOM ou 1-6 HETATM */			/*C 01*/
	char ATOM_HETAM[6];					/*01*/
					/* 7-11 Atom serial number */			/*C 02*/
	long ATOM_serialnumber;					/*02*/
					/* 13-16 Atom name *//*A 01*/
	char ATOM_name[NB_M_LG];				/*03*/			/*C 03*/
					/* 17 alternate location indicator*/
	char ATOM_altloc;		/* c'est un caractere *//*04*/			/*C 04*/
					/* 18-20 Residues name */
	char ATOM_residuesname[NB_M_LG];			/*05*/			/*C 05*/
					/* 22 chain identifier */
					
	char ATOM_chainnumber;					/*06*/			/*C 06*/
								/* le classique */
	long  ATOM_ichainnumber;				/*06*/			/*C 07*/
								/* rencontre met alors 'Z' dans le precedent */
					/* 23-26  residues seq number */
					
	long ATOM_residuesnumber;				/*07*/			/*C 08*/
					/* 27 code for insertions of residues */
	char ATOM_insert;					/*08*/			/*C 09*/
					/* 31-38 X orthogonal angstrom coordinates */
	double ATOM_CoordX;					/*09*/			/*C 10*/
					/* 39-46 Y // */
	double ATOM_CoordY;					/*10*/			/*C 11*/
					/* 47-54 Z // */
	double ATOM_CoordZ;					/*11*/			/*C 12*/
					/* 55-60 Occupency */

	double ATOM_Occupancy;					/*12*/			/*C 13*/
					/* 61-66 Temperature Factor */
	double ATOM_TemperatureFactor;				/*13*/			/*C 14*/
	char ATOM_real;									/*C 15*/
								/* le vrai type de l'atome C,H,N,O,P,S...*/

	short int ATOM_ls;		/* 68-70 Footnote number */

	/*long ATOM_Footnote[10];*/		/* voir pour alterne */	/*13*/	
	/*char ATOM_endline;*/					/*14*/
	/*long  ATOM_endline2;*/					/*14b*/
	/*char ATOM_type[10];*/					/*15*/
	/*struct dist ATOM_dist[10];*/				/*16*/

	};						


struct mactype{			/* format mac (exp.) */
	long ATOMc_type;				/* le type de l'atome */
	double ATOMc_CoordX;				/*   coordonnees 3D   */
	double ATOMc_CoordY;				/*   coordonnees 3D   */
	double ATOMc_CoordZ;				/*   coordonnees 3D   */
	long CONNECT[MAX_CONEX];			/* connections autorises*/
	
};

	/****************************************/
	/*      structure de la molecule        */
	/****************************************/

struct __pdbfile{
	short int IsItProt;
	short int IsItCalphaOnly;
	short int IsItDNA;
	short int WhichExp;

							/*****************************/
	char header[NB_AMX_HEADER];			/*         descriptif        *//* A 01*/
	char name[8];					/*     nom de la proteine    *//* A 02*/
	long lg_header;					/*    longeur du header      *//* A 03*/
	struct atomtype pdbatomtype[NB_MAX_ATOM];	/*les atomes proprements dits*//* A 04*/
	long NbAtome;					/*    le nombre d'atomes     *//* A 06*/
	double resolution;				/*     la resolution en A    *//* A 07*/
	char depositdate[250];
	char releasedate[250];
							/*****************************/
	
			/*        le residu en tant que tel  (aa)        */
		
							/*****************************/
	long Nb_residues;				/*    nombre de residues     *//* B 01*/
	long deb_residues[NB_MAX_RES];			/*debut du res. dans fichier *//* B 02*/
	long end_residues[NB_MAX_RES];			/*  fin du res. dans fichier *//* B 03*/
	char Nam_residues[NB_MAX_RES];			/* nom a 1 lettre du residue *//* B 04*/
	char Complete_Res[NB_MAX_RES];			/*    aa complet ou non      *//* B 05*/
	double Phi[NB_MAX_RES];				/*        angle Phi          *//* B 06*/
	double Psi[NB_MAX_RES];				/*        angle Psi          *//* B 07*/
	double Omega[NB_MAX_RES];			/*       angle Omega         *//* B 08*/
	double Xhi[NB_MAX_RES][NB_MAX_XHI];		/*      les angle Chi(s)     *//* B 09*/
	long Composition_AA[NbrAA];			/*  composition en ac.amines *//* B 10*/
	short int NB_chain;				/*    le nombre de chaines   *//* B 11*/
	short int Assign_PB[NB_MAX_RES];		/*  le BSP assigne au residu *//* B 13*/

	double New_Phi[NB_MAX_RES];			/*  angle Phi reconstruit    *//* B 14*/
	double New_Psi[NB_MAX_RES];			/*  angle Psi reconstruit    *//* B 15*/
	double Nea_Phi[NB_MAX_RES];			/*  angle Phi le plus proche *//* B 16*/
	double Nea_Psi[NB_MAX_RES];			/*  angle Psi le plus proche *//* B 17*/
	
	long Pos_FirstRes[NB_MAX_RES];			/*debut du res. dans fichier *//* B 20*/
	long Pos_LastRes[NB_MAX_RES];			/* fin du res. dans fichier  *//* B 21*/
	
	long Deb_chain[NB_MAX_CHAIN];			/*     debut residu chaine   *//* B 18*/
	long End_chain[NB_MAX_CHAIN];			/*     debut residu chaine   *//* B 19*/
	long Pos_chain[NB_MAX_CHAIN][2];		/*   debut et fin de chaine  *//* B 12*/
	double meanTval;				/*	valeur moyenne des R */ /* 16-12-2005 */
	double meanTvalsd;				/*	valeur moyenne des R */ /* 16-12-2005 */
	
	long PB_latChain;				/* probleme dans les ch. lat */
	long PB_Backbone;				/* probleme sur le backbone  */
	long PB_AA;					/*     nb aa indetermine     */
	long PB_Doublet;				/*     nombre d'alt. loc.    */			/* 16/12/99 */
							/*****************************/	
	
	long Next_AA[NB_MAX_RES];			/* le prochain aa est a +1   */ 		/* 17/06/00 */
	float Alpha[NB_MAX_RES];			/* l'angle alpha du backbone */			/* 30/06/00 */
	char S2sea[NB_MAX_RES];				/*  la extern structure secondaire  */			/* 25/08/00 */
	char S2dssp[NB_MAX_RES];			/*  la extern structure secondaire  */			/* 28/08/00 */	
	char S2dsspcont[NB_MAX_RES];			/*  la extern structure secondaire  */			/* 31/07/03 */		
	char S2dssphel[NB_MAX_RES];			/*  la extern structure secondaire  */			/* 18/08/03 */		
	char S2stride[NB_MAX_RES];			/*  la extern structure secondaire  */			/* 29/08/00 */	
	char S2define[NB_MAX_RES];			/*  la extern structure secondaire  */			/* 30/08/00 */									
	char S2pcurve[NB_MAX_RES];			/*  la extern structure secondaire  */			/* 31/08/00 */
	char S2xtlsstr[NB_MAX_RES];			/*  la extern structure secondaire  */			/* 13/08/03 */
	char S2RKdssp[NB_MAX_RES];			/*  la extern structure secondaire  */			/* 30/01/04 */
	char S2Fodje[NB_MAX_RES];			/*  la extern structure secondaire  */			/* 02/02/04 */
	char S2Segno[NB_MAX_RES];			/*  la extern structure secondaire  */			/* 26/05/05 */
	char S2Kaksi[NB_MAX_RES];			/*  la extern structure secondaire  */			/* 26/05/05 */
	
	
	short int BetaTurnPro[NB_MAX_RES][9];		/*      la extern Promotif          */			/* 31/03/03 */					
	short int GammaTurnPro[NB_MAX_RES][2];		/*      la extern Promotif     */			/* 31/03/03 */					
	short int BetaHairpinPro[NB_MAX_RES];		/*      la extern Promotif     */			/* 31/03/03 */	
	short int BetaBulPro[NB_MAX_RES];		/*      la extern Promotif     */			/* 16/02/04 */			
	int BetaBulProX[NB_MAX_RES];			/*      la extern Promotif     */			/* 16/02/04 */		
	short int PsiLoopPro[NB_MAX_RES];		/*      la extern Promotif     */			/* 10/02/04 */		
	
	short int Turn_Type1[NB_MAX_RES];		/*  intern definition of turn type I    */		/* 12/06/03 */	
	short int Turn_Type2[NB_MAX_RES];		/*  intern definition of turn type II   */		/* 12/06/03 */		
	short int Turn_Type8[NB_MAX_RES];		/*  intern definition of turn type VIII */		/* 12/06/03 */		
	short int Turn_Type1I[NB_MAX_RES];		/*  intern definition of turn type I'   */		/* 12/06/03 */			
	short int Turn_Type2I[NB_MAX_RES];		/*  intern definition of turn type II'  */		/* 12/06/03 */			
	short int Turn_Type6a1[NB_MAX_RES];		/*  intern definition of turn type VIa1 */		/* 12/06/03 */		
	short int Turn_Type6a2[NB_MAX_RES];		/*  intern definition of turn type VIa2 */		/* 12/06/03 */		
	short int Turn_Type6b[NB_MAX_RES];		/*  intern definition of turn type VIb  */		/* 12/06/03 */		
	short int Turn_Type4[NB_MAX_RES];		/*  intern definition of turn type IV   */		/* 12/06/03 */		
	
	short int Turn_GammaClass[NB_MAX_RES];		/*  intern definition of Gamma turn     */		/* 13/06/03 */		
	short int Turn_GammaClassI[NB_MAX_RES];		/*  intern definition of Gamma inverse  */		/* 13/06/03 */				
	
	short int Turn_Alpha[NB_MAX_RES][NB_ALPHA_TURN];/*  intern definition of Alpha turns */		/* 15/06/02 */				
		
	float RelativeAccess[NB_MAX_RES];		/* l'accessibilite */				/* 19/12/05 */
	short int CysDSSP[NB_MAX_RES];			/* cysteine - cystine by DSSP */			/* 19/12/05 */
	
	struct seqres pdbseqres[NB_MAX_RES];		/* 09/04/03 */
	struct seqreschain pdbseqreschain;		/* 09/04/03 */
	
	struct helix pdbhelix;				/* 10/04/03 */
	struct beta pdbbeta;				/* 14/04/03 */
	struct turn pdbturn;				/* 14/04/03 */
					
							/*	Acid Nucleique :	*/					
	long Nb_AtNA;		
	};

typedef struct __pdbfile pdbfile;


extern char *First[];
extern long CONNECT_MAX_number[];
extern char *CONNECT_traduction[];
extern char *R_type[];
extern char Trans_R_type[];
extern char *D_type[];
extern char Trans_D_type[];
extern char *AA_3_Letter[];
extern char AA_1_Letter[];
extern long Lg_AA[];
extern long Usable_Lg_AA[];
extern long NB_XHI[];
extern long UseAtXhi[NB_MAX_XHI][4];
extern char *Prot_Min_AA[NbrAA][LG_MAX_AA];
extern char *Designa_NuclAcid[];
extern char *Prot_Modlr_AA[NbrAA][LG_MAX_AA];	


extern double gamma_turn[NB_GAMMA_TURN][2];
extern char *gamma_turn_name[NB_GAMMA_TURN];
extern char *gamma_turn_ref;
extern char *gamma_turn_note;


extern double beta_turn[NB_BETA_TURN-1][4];
extern char *beta_turn_name[NB_BETA_TURN];
extern char *beta_turn_ref;
extern char *beta_turn_note;

extern double alpha_turn[NB_ALPHA_TURN][6];
extern char *alpha_turn_name[NB_ALPHA_TURN];
extern char *alpha_turn_ref;
extern char *alpha_turn_note;

extern char *PBs_ref;
extern char *SWs_ref;

extern double Kolodny_10_5[10][5][3];
extern double Kolodny_20_5[20][5][3];
char *kolo_ref;

double Oligons[40][5][3];
char *Oligons_ref;


extern char *dssp_name[NB_DSSP_STATE];
extern char *short_dssp_name[NB_DSSP_STATE];
extern char *dssp_ref;
extern char *stride_ref;
extern char *stride_notes;
extern char *psea_name[NB_psea_STATE];
extern char *short_psea_name[NB_psea_STATE];
extern char *psea_ref;
extern char *define_name[NB_psea_STATE];
extern char *short_define_name[NB_psea_STATE];
extern char *define_ref;
extern char *pcurve_name[NB_psea_STATE];
extern char *short_pcurve_name[NB_psea_STATE];
extern char *pcurve_ref;
extern char *pcons93_ref;
extern char *xtllstr_name[NB_XTLSSTR_STATE];
extern char *short_xtllstr_name[NB_XTLSSTR_STATE];
extern char *xtllstr_ref;
extern char *helanal_name[NB_HELANAL_STATE];
extern char *short_helanal_name[NB_HELANAL_STATE];
extern char *helanal_ref;
extern char *dssprk_name[NB_DSSPRK_STATE];
extern char *short_dssprk_name[NB_DSSPRK_STATE];
extern char *dssprk_ref;
extern char *dssprk_notes;
extern char *secstr_name[NB_secstr_STATE];
extern char *short_secstr_name[NB_secstr_STATE];
extern char *secstr_ref;
extern char *segno_name[NB_segno_STATE];
extern char *short_segno_name[NB_segno_STATE];
extern char *segno_ref;

extern char *betabul_name[NB_betabul_STATE];
extern char *short_betabul_name[NB_betabul_STATE];
extern char *betabul_ref;

