# include <stdio.h>
# include <stdlib.h>
# include <string.h>
# include <math.h>
# include <time.h>
# include <assert.h>
# include <sys/wait.h>

# include "../HEADER/lib_define.h"
# include "../HEADER/options.h"				
# include "../HEADER/lib_protoC.h"
# include "../HEADER/lib_local_secstr.h"

/****************************/
/* all secondary structures */
/****************************/

char CtoI(int a){
	char entier;
	switch (a){
		case (0): entier='H'; break;
		case (1): entier='C'; break;
		case (2): entier='E'; break;
		default :   entier='-';  break; 
		};
	return (entier);
	}

/************/
/* 00- DSSP */
/************/

int TroisEtatsDssp(char a){
	int entier;
	switch (a){
		case ('H'): entier=0; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case ('G'): entier=0; break;	/*  	'G'  		==> helice 3.10 	(0) */
		case ('I'): entier=0; break;	/*   Pi -helix    	==> helice - pi 	(0) */
		case ('T'): entier=1; break;	/* 	turns 		==>  coudes		(1) */
		case ('S'): entier=1; break;	/* 	bend		==>  coudes		(1) */
		case ('C'): entier=1; break;	/* 	coils 		==>  boucles		(1) */
		case (' '): entier=1; break;	/* 	coils 		==>  boucles		(1) */
		case ('B'): entier=1; break;	/* residue in isolated beta-bridge  ==> 	(1) */
		case ('b'): entier=1; break;	/* residue in isolated beta-bridge  ==> 	(1) */
		case ('E'): entier=2; break;	/* extended conformation ==> feuillet beta 	(2) */
		case ('U'): entier=3; break;	/*  Not readable */
		default :   entier=3; printf("pb de structure secondaire de type [%c] TroisEtatsDssp\n",a); break;
		};
	return (entier);
	}


int CEightDssp(char a){
	int entier;
	switch (a){
		case ('H'): entier=0; /* Alpha -helix */	break;
		case ('G'): entier=1; /*  3.10 -helix */ 	break;
		case ('I'): entier=2; /*   Pi -helix  */	break;
		case ('T'): entier=3; /*    Turn      */	break;
		case ('S'): entier=4; /*     bend     */	break;
		case (' '): entier=5; /*      coil    */	break;		
		case ('C'): entier=5; break;	
		case ('L'): entier=5; break;			
		case ('B'): entier=6; /* isol. beta b.*/	break;
		case ('b'): entier=6; /* isol. beta b.*/	break;
		case ('E'): entier=7; /*   extended   */	break;
		case ('U'): entier=8; /*  Not readable */ 	break;
		default :   entier=8; printf("pb de structure secondaire de type [%c] CEightDssp \n",a); break;
		};
	return (entier);
	}

char ReverseEight(int a){
	char entier;
	switch (a){
		case (0): entier='H'; /* Alpha -helix */	break;
		case (1): entier='G'; /*  3.10 -helix */ 	break;
		case (2): entier='I'; /*   Pi -helix  */	break;
		case (3): entier='T'; /*    Turn      */	break;
		case (4): entier='S'; /*     bend     */	break;
		case (5): entier=' '; /*      coil    */	break;		
		case (6): entier='B'; /* isol. beta b.*/	break;
		case (7): entier='E'; /*   extended   */	break;
		case (8): entier='U'; /* Not readable */ 	break;
		default :   entier='U'; printf("pb de structure secondaire de type [%d] ReverseEightDssp \n",a); break;
		};
	return (entier);
	}

char ReverseEightC(char a){
	char entier;
	switch (a){
		case ('H'): entier='H'; /* Alpha -helix */	break;
		case ('G'): entier='G'; /*  3.10 -helix */ 	break;
		case ('I'): entier='I'; /*   Pi -helix  */	break;
		case ('T'): entier='T'; /*    Turn      */	break;
		case ('S'): entier='S'; /*     bend     */	break;
		case (' '): entier='C'; /*      coil    */	break;		
		case ('C'): entier='C'; /*      coil    */	break;		
		case ('B'): entier='B'; /* isol. beta b.*/	break;
		case ('E'): entier='E'; /*   extended   */	break;
		case ('U'): entier='U'; /* Not readable */ 	break;
		default :   entier='U'; printf("pb de structure secondaire de type [%d] ReverseEightDssp \n",a); break;
		};
	return (entier);
	}


/**************/
/* 01- STRIDE */
/**************/

int TroisEtatsStride(char a){
	int entier;
	switch (a){
		case ('H'): entier=0; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case ('G'): entier=0; break;	/*  	'G'  		==> helice 3.10 	(0) */
		case ('I'): entier=0; break;	/*   Pi -helix    	==> helice - pi 	(0) */
		case ('T'): entier=1; break;	/* 	turns 		==>  coudes		(1) */
		case ('S'): entier=1; break;	/* 	bend		==>  coudes		(1) */
		case (' '): entier=1; break;	/* 	coils 		==>  boucles		(1) */
		case ('C'): entier=1; break;	/* 	coils 		==>  boucles		(1) */
		case ('B'): entier=1; break;	/* residue in isolated beta-bridge  ==> 	(1) */
		case ('b'): entier=1; break;	/* residue in isolated beta-bridge  ==> 	(1) */
		case ('E'): entier=2; break;	/* extended conformation ==> feuillet beta 	(2) */
		case ('U'): entier=3; break;	/*  Not readable */
		default :   entier=3; printf("pb de structure secondaire de type [%c] TroisEtatsStride\n",a); break;
		};
	return (entier);
}

/************/
/* 02- PSEA */
/************/

char HighSEA(char a){
	char entier;
	switch (a){
		case ('a'): entier='H'; break;
		case ('c'): entier='C'; break;
		case ('b'): entier='E'; break;
		default :   entier='-'; printf("pb de structure secondaire [%c] HighSEA\n",a);
		};
	return (entier);
	}

int TroisEtatsPsea(char a){
	int entier;
	switch (a){
		case ('a'): entier=0; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case ('c'): entier=1; break;	/* coils 		==>  boucles		(1) */
		case ('b'): entier=2; break;	/*extended conformation ==> feuillet beta 	(2) */
		default :   entier=3; printf("pb de structure secondaire de type [%c] P-SEA\n",a);
		};
	return (entier);
	}
	
char ReverseSea(int a){
	char entier;
	switch (a){
		case (0): entier='a'; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case (1): entier='c'; break;	/* coils 		==>  boucles		(1) */
		case (2): entier='b'; break;	/*extended conformation ==> feuillet beta 	(2) */
		default :   entier='X'; printf("pb de structure secondaire de type [%c] ReverseSea\n",a);
		};
	return (entier);
	}

/**************/
/* 03- DEFINE */
/**************/

int TroisEtatsDefine(char a){
	int entier;
	switch (a){
		case ('A'): entier=0; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case ('C'): entier=1; break;	/* coils 		==>  boucles		(1) */
		case ('B'): entier=2; break;	/*extended conformation ==> feuillet beta 	(2) */
		default :   entier=3; printf("pb de structure secondaire de type [%c] DEFINE\n",a);
		};
	return (entier);
	}

char HighDefine(char a){
	char entier;
	switch (a){
		case ('A'): entier='H'; break;
		case ('C'): entier='C'; break;
		case ('B'): entier='E'; break;
		default :   entier='-'; printf("pb de structure secondaire \n");
		};
	return (entier);
	}

char ReverseDefine(int a){
	char entier;
	switch (a){
		case (0): entier='A'; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case (1): entier='C'; break;	/* coils 		==>  boucles		(1) */
		case (2): entier='B'; break;	/*extended conformation ==> feuillet beta 	(2) */
		default :   entier='X'; printf("pb de structure secondaire de type [%c] ReverseDefine\n",a);
		};
	return (entier);
	}

	

/**************/
/* 04- Pcurve */
/**************/

int TroisEtatsPcurve(char a){
	int entier=-1;
	switch (a){
		case ('+'): entier=0; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case (' '): entier=1; break;	/* coils 		==>  boucles		(1) */
		case ('-'): entier=2; break;	/*extended conformation ==> feuillet beta 	(2) */
		default :   entier=3; printf("pb de structure secondaire de type [%c] P-CURVE\n",a);
		};
	return (entier);
	}

char HighPcurve(char a){
	char entier;
	switch (a){
		case ('+'): entier='H'; break;
		case (' '): entier='C'; break;
		case ('-'): entier='E'; break;
		default :   entier='-'; printf("pb de structure secondaire (HighPcurve) \n");
		};
	return (entier);
	}

char Reversecurve(int a){
	char entier;
	switch (a){
		case (0): entier='+'; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case (1): entier=' '; break;	/* coils 		==>  boucles		(1) */
		case (2): entier='-'; break;	/*extended conformation ==> feuillet beta 	(2) */
		default :   entier='X'; printf("pb de structure secondaire de type [%c] P-CURVE\n",a);
		};
	return (entier);
	}

/***************/
/* 05- xtlsstr */
/***************/

int TroisEtatsxtls(char a){
	int entier=-1;
	switch (a){
		case ('H'): entier=0; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case ('h'): entier=0; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case ('G'): entier=0; break;	/*  	'G'  		==> helice 3.10 	(0) */
		case ('g'): entier=0; break;	/*  	'g'  		==> helice 3.10 end	(0) */
		case ('T'): entier=1; break;	/* 	turns 		==>  coudes		(1) */
		case ('N'): entier=1; break;	/*   turns-like		==>  coudes		(1) */
		case ('P'): entier=1; break;	/*  polyproline II type (3-1) helix		==>  		(1) */
		case ('p'): entier=1; break;	/*  polyproline II type (3-1) helix		==>  		(1) */		
		case ('-'): entier=1; break;	/* 	coils 		==>  boucles		(1) */			
		case (' '): entier=1; break;	/* 	coils 		==>  boucles		(1) */
		case ('E'): entier=2; break;	/* extended conformation ==> feuillet beta 	(2) */
		case ('e'): entier=2; break;	/* extended conformation ==> feuillet beta 	(2) */		
		default :   entier=3; printf("pb de structure secondaire de type [%c] TroisEtatsxtls\n",a); break;
		};
	return (entier);
	}

int EightEtatsxtls(char a){
	int entier=-1;
	switch (a){
		case ('H'): entier=0; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case ('h'): entier=0; break;	/* Alpha -helix 	==> helice - alpha 	(0) */		
		case ('G'): entier=1; break;	/*  	'G'  		==> helice 3.10 	(0) */
		case ('g'): entier=2; break;	/*  	'g'  		==> helice 3.10 end	(0) */
		case ('T'): entier=3; break;	/* 	turns 		==>  coudes		(1) */
		case ('N'): entier=4; break;	/*   turns-like		==>  coudes		(1) */
		case ('P'): entier=5; break;	/*  polyproline II type (3-1) helix		==>  		(1) */
		case ('p'): entier=6; break;	/*  polyproline II type (3-1) helix		==>  		(1) */		
		case ('-'): entier=7; break;	/* 	coils 		==>  boucles		(1) */			
		case (' '): entier=7; break;	/* 	coils 		==>  boucles		(1) */
		case ('E'): entier=8; break;	/* extended conformation ==> feuillet beta 	(2) */
		case ('e'): entier=8; break;	/* extended conformation ==> feuillet beta 	(2) */
		default :   entier=9; printf("pb de structure secondaire de type [%c] EightEtatsxtls\n",a); break;
		}
	return (entier);
	}

char ReverseEightEtatsxtls(int a){
	char entier=-1;
	switch (a){
		case (0): entier='H'; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case (1): entier='G'; break;	/*  	'G'  		==> helice 3.10 	(0) */
		case (2): entier='g'; break;	/*  	'g'  		==> helice 3.10 end	(0) */
		case (3): entier='T'; break;	/* 	turns 		==>  coudes		(1) */
		case (4): entier='N'; break;	/*   turns-like		==>  coudes		(1) */
		case (5): entier='P'; break;	/*  polyproline II type (3-1) helix		==>  		(1) */
		case (6): entier='p'; break;	/*  polyproline II type (3-1) helix		==>  		(1) */		
		case (7): entier='-'; break;	/* 	coils 		==>  boucles		(1) */			
		case (8): entier='E'; break;	/* extended conformation ==> feuillet beta 	(2) */
		default :   entier='X'; printf("pb de structure secondaire de type [%d] ReverseEightEtatsxtls\n",a); break;
		}
	return (entier);
	}

char AdaptXtl(char a){

	char entier='U';
	switch (a){
		case ('H'): entier='H'; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case ('G'): entier='G'; break;	/*  	'G'  		==> helice 3.10 	(0) */
		case ('g'): entier='G'; break;	/*  	'g'  		==> helice 3.10 end	(0) */
		case ('T'): entier='T'; break;	/* 	turns 		==>  coudes		(1) */
		case ('N'): entier='N'; break;	/*   turns-like		==>  coudes		(1) */
		case ('P'): entier='P'; break;	/*  polyproline II type (3-1) helix		==>  		(1) */
		case ('p'): entier='P'; break;	/*  polyproline II type (3-1) helix		==>  		(1) */		
		case ('C'): entier='C'; break;	/* 	coils 		==>  boucles		(1) */			
		case (' '): entier='C'; break;	/* 	coils 		==>  boucles		(1) */					
		case ('-'): entier='C'; break;	/* 	coils 		==>  boucles		(1) */			
		case ('E'): entier='E'; break;	/* extended conformation ==> feuillet beta 	(2) */
		default :   entier='U'; printf("pb de structure secondaire de type [%c] ReverseEightEtatsxtls\n",a); break;
		}
	return (entier);
	}



/***************/
/* 06- HELANAL */
/***************/

char ReverseFiveEtatshel(int a){
	int entier;
	switch (a){
		case (0): entier='H'; /* Alpha -helix too short	*/	break;
		case (1): entier='L'; /*     linear helix	*/ 	break;
		case (2): entier='C'; /*     curved helix  	*/	break;
		case (3): entier='K'; /*    kinked helix        */	break;
		case (4): entier='*'; /*     unsassigned        */	break;
		case (5): entier='-'; /*   not helicoidal    	*/	break;		
		default :   entier='X'; printf("pb de structure secondaire de type [%c] ReverseFiveEtatshel \n",a); break;
		};
	return (entier);
	} 

int FiveStateHel(char a){
	int entier;
	switch (a){
		case ('H'): entier=0; /* Alpha -helix too short	*/	break;
		case ('L'): entier=1; /*     linear helix	*/ 	break;
		case ('C'): entier=2; /*     curved helix  	*/	break;
		case ('K'): entier=3; /*    kinked helix        */	break;
		case ('*'): entier=4; /*     unsassigned        */	break;
		case ('-'): entier=5; /*   not helicoidal    	*/	break;		
		default :   entier=6; printf("pb de structure secondaire de type [%c] FiveStateHel \n",a); break;
		};
	return (entier);
	} 

char AdaptHel(char a){
	char entier;
	switch (a){
		case ('H'): entier='s'; /* Alpha -helix too short	*/	break;
		case ('L'): entier='l'; /*     linear helix	*/ 	break;
		case ('C'): entier='v'; /*     curved helix  	*/	break;
		case ('K'): entier='k'; /*    kinked helix        */	break;
		case ('*'): entier='n'; /*     unsassigned        */	break;
		case ('-'): entier='-'; /*   not helicoidal    	*/	break;		
		default :   entier='U'; printf("pb de structure secondaire de type [%c] FiveStateHel \n",a); break;
		};
	return (entier);
	} 
/**************************/
/* 07- Rachel Karchin     */
/* extended dssp alphabet */
/**************************/

/*
#A script to generate dssp strings in fasta format from dssp files using an extended dssp alphabet
# B,G,H,I,T,S,C as in dssp
# + P= paralle in sheet; Q= paralle edge; A=antiparallel sheet; Z= antiparallel edge; M= parallel and antiparallel mixed  
*/
int DouzEtatsDsspRK(char a){
	int entier;
	switch (a){
		case ('H'): entier=0; /* Alpha -helix */	break;
		case ('G'): entier=1; /*  3.10 -helix */ 	break;
		case ('I'): entier=2; /*   Pi -helix  */	break;
		case ('T'): entier=3; /*    Turn      */	break;
		case ('S'): entier=4; /*     bend     */	break;
		case (' '): entier=5; /*      coil    */	break;		
		case ('C'): entier=5; break;	
		case ('L'): entier=5; break;			
		case ('B'): entier=6; /* isol. beta b.*/	break;
		case ('b'): entier=6; /* isol. beta b.*/	break;
		case ('P'): entier=7;	break;
		case ('Q'): entier=8;	break;
		case ('A'): entier=9;	break;
		case ('Z'): entier=10;	break;						
		case ('M'): entier=11;	break;	
		case ('E'): entier=12;	break;	
		case ('U'): entier=13; /*  Not readable */ 	break;
		default :   entier=13; printf("pb de structure secondaire de type [%c] DouzEtatsDsspRK \n",a); break;
		};
	return (entier);
	}

char ReverseDouzEtatsDsspRK(int a){
	char entier;
	switch (a){
		case (0): entier='H'; /* Alpha -helix */	break;
		case (1): entier='G'; /*  3.10 -helix */ 	break;
		case (2): entier='I'; /*   Pi -helix  */	break;
		case (3): entier='T'; /*    Turn      */	break;
		case (4): entier='S'; /*     bend     */	break;
		case (5): entier='C'; /*      coil    */	break;		
		case (6): entier='B'; /* isol. beta b.*/	break;
		case (7): entier='P';	break;
		case (8): entier='Q';	break;
		case (9): entier='A';	break;
		case (10): entier='Z';	break;						
		case (11): entier='M';	break;		
		case (12): entier='E';	break;		
		case (13): entier='U'; /*  Not readable */ 	break;
		default :   entier=13; printf("pb de structure secondaire de type [%c] DouzEtatsDsspRK \n",a); break;
		};
	return (entier);
	}
	
char AdaptDouzEtatsDsspRK(char a){
	char entier;
	switch (a){
		case ('H'): entier='-'; /* Alpha -helix */	break;
		case ('G'): entier='-'; /*  3.10 -helix */ 	break;
		case ('I'): entier='-'; /*   Pi -helix  */	break;
		case ('T'): entier='-'; /*    Turn      */	break;
		case ('S'): entier='-'; /*     bend     */	break;
		case ('C'): entier='-'; /*      coil    */	break;		
		case ('B'): entier='b'; /* isol. beta b.*/	break;
		case ('P'): entier='p';	break;
		case ('Q'): entier='q';	break;
		case ('A'): entier='a';	break;
		case ('Z'): entier='z';	break;						
		case ('M'): entier='m';	break;		
		case ('E'): entier='e';	break;		
		case ('U'): entier='U'; /*  Not readable */ 	break;
		default :   entier=13; printf("pb de structure secondaire de type [%c] DouzEtatsDsspRK \n",a); break;
		};
	return (entier);
	}
	
/************/
/* Fodje    */
/* Pi-helix */
/************/

int EtatsFodje(char a){
	int entier;
	switch (a){
		case ('H'): entier=0; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case ('G'): entier=1; break;	/*  	'G'  		==> helice 3.10 	(1) */
		case ('I'): entier=2; break;	/*   Pi -helix    	==> helice - pi 	(2) */
		case (' '): entier=3; break;	/*   coil 					  */
		case ('C'): entier=3; break;	/*   coil 					  */
		case ('E'): entier=4; break;	/* extended conformation ==> feuillet beta 	() */
		case ('e'): entier=4; break;	/* extended conformation ==> feuillet beta 	() */
		case ('U'): entier=5; break;	/*  Not readable */
		default :   entier=5; printf("pb de structure secondaire de type [%c] EtatsFodje\n",a); break;
		};
	return (entier);
}

int TroisEtatsFodje(char a){
	int entier;
	switch (a){
		case ('H'): entier=0; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case ('G'): entier=0; break;	/*  	'G'  		==> helice 3.10 	(1) */
		case ('I'): entier=0; break;	/*   Pi -helix    	==> helice - pi 	(2) */
		case (' '): entier=1; break;	/*   coil 					  */
		case ('C'): entier=1; break;	/*   coil 					  */
		case ('E'): entier=2; break;	/* extended conformation ==> feuillet beta 	() */
		case ('e'): entier=2; break;	/* extended conformation ==> feuillet beta 	() */
		case ('U'): entier=3; break;	/*  Not readable */
		default :   entier=3; printf("pb de structure secondaire de type [%c] EtatsFodje\n",a); break;
		};
	return (entier);
}

char ReverseEtatsFodje(int a){
	int entier;
	switch (a){
		case (0): entier='H'; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case (1): entier='G'; break;	/*  	'G'  		==> helice 3.10 	(1) */
		case (2): entier='I'; break;	/*   Pi -helix    	==> helice - pi 	(2) */
		case (3): entier=' '; break;	/*   coil 					  */
		case (4): entier='E'; break;	/* extended conformation ==> feuillet beta 	() */
		case (5): entier='U'; break;	/*  Not readable */
		default :   entier=5; printf("pb de structure secondaire de type [%c] EtatsFodje\n",a); break;
		};
	return (entier);
}

char AdaptFod(char a){
	char entier;
	switch (a){
		case ('H'): entier='H'; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case ('G'): entier='G'; break;	/*  	'G'  		==> helice 3.10 	(1) */
		case ('I'): entier='I'; break;	/*   Pi -helix    	==> helice - pi 	(2) */
		case (' '): entier='C'; break;	/*   coil 					  */
		case ('C'): entier='C'; break;	/*   coil 					  */
		case ('E'): entier='E'; break;	/* extended conformation ==> feuillet beta 	() */
		case ('U'): entier='U'; break;	/*  Not readable */
		default :   entier=5; printf("pb de structure secondaire de type [%c] EtatsFodje\n",a); break;
		};
	return (entier);
}



/************/
/* SEGNO    */
/************/

int EtatsSegno(char a){
	int entier;
	switch (a){
		case ('H'): entier=0; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case ('h'): entier=0; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case ('G'): entier=1; break;	/*  	'G'  		==> helice 3.10 	(1) */
		case ('g'): entier=1; break;	/*  	'G'  		==> helice 3.10 	(1) */
		case ('I'): entier=2; break;	/*   Pi -helix    	==> helice - pi 	(2) */
		case ('i'): entier=2; break;	/*   Pi -helix    	==> helice - pi 	(2) */		
		case ('P'): entier=3; break;	/*  PII  */
		case ('p'): entier=3; break;	/*  PII  */
		case ('O'): entier=4; break;	/*   coil 					  */
		case ('E'): entier=5; break;	/* extended conformation ==> feuillet beta 	() */
		case ('e'): entier=5; break;	/* extended conformation ==> feuillet beta 	() */
		case ('B'): entier=6; break;	/* 	() */
		case ('b'): entier=6; break;	/* 	() */
		case ('U'): entier=7; break;	/*  Not readable */
		default :   entier=7; printf("pb de structure secondaire de type [%c] EtatsSegno\n",a); break;
		};
	return (entier);
}


/*********/
/* Kaksi */
/*********/

int EtatsKaksi(char a){
	int entier;
	
	/*printf("%c\n",a);*/
	switch (a){
		case ('H'): entier=0; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case ('h'): entier=0; break;	/* Alpha -helix 	==> helice - alpha 	(0) */
		case ('.'): entier=1; break;
		case ('B'): entier=2; break;	/* 	() */
		case ('b'): entier=2; break;	/* 	() */
		case ('U'): entier=3; break;	/*  Not readable */
		default :   entier=3; printf("pb de structure secondaire de type [%c] EtatsKaksi\n",a); break;
		};
	return (entier);
}

