/******************************************************************************/
/*	PDB Dreamer version x.yz					      */
/*      (A.G. de Brevern - EBGM - E0346 INSERM)				      */
/******************************************************************************/
/*	promotif_read.c	(beta version 2004)				      */
/*	---------------							      */
/*	Promotif was written by E. G. Hutchinson			      */
/*	Copyright 1995 University College London			      */
/*	(please ask for a license at :					      */
/*	http://www.biochem.ucl.ac.uk/~gail/promotif/promotif.html)	      */
/*	A compatible linux version was cleaned at the EBGM		      */
/*	The script which is used is called promotif2			      */
/*	and could be found with this code uder the name 'promotif2.scr'       */
/******************************************************************************/

# include <stdio.h>
# include <stdlib.h>
# include <string.h>
# include <math.h>
# include <time.h>
# include <assert.h>
# include <sys/wait.h>

# include "../HEADER/lib_define.h"
# include "../HEADER/options.h"				
# include "../HEADER/lib_protoC.h"

void ligne_pdb(pdbfile *m, FILE *f_f, long i,long j){
	
	fprintf(f_f,"ATOM   %4.0ld  %-3s%4s %c%4ld ",j,m->pdbatomtype[j].ATOM_name,m->pdbatomtype[j].ATOM_residuesname,'A',m->pdbatomtype[j].ATOM_residuesnumber);
	fprintf(f_f,"   %8.3f%8.3f%8.3f  1.00 19.19             %c\n",m->pdbatomtype[j].ATOM_CoordX,m->pdbatomtype[j].ATOM_CoordY,m->pdbatomtype[j].ATOM_CoordZ,m->pdbatomtype[j].ATOM_real);
								

}


void WritePartPdb(pdbfile *m,long begin,long end, long underscore){

	FILE *f_pdbout;
	char file_name[SIZE_Buffer];
	long i_loc,j_loc;
	
	sprintf(file_name,"Results/Rasmol/%s_%ld.pdb",m->name,underscore);
	
	f_pdbout=fecrire(file_name);
	
	fprintf(f_pdbout,"HEADER\t\t\t\t\t%4s%c %6ld AdB  %1.1f\n",m->name,'A',end-begin,m->resolution);
	fprintf(f_pdbout,"REMARK\t PSI-LOOPS cut-cut [%ld-%ld]\n",begin,end);
	for(i_loc=begin;i_loc<end;i_loc++){
		for(j_loc=m->deb_residues[i_loc];j_loc<m->end_residues[i_loc]+1;j_loc++){
			ligne_pdb(m,f_pdbout,i_loc,j_loc);
			}
		}	
	fprintf(f_pdbout,"END\n");		
	of(f_pdbout);
}


void WriteRasmolPsiLoops(pdbfile* m,long deb1,long deb2,long fin1,long fin2,long under){

	FILE *fout;
	char file_name[SIZE_Buffer];
	
	sprintf(file_name,"Results/Rasmol/%s_%ld.ras",m->name,under);
	
	/*printf("%ld %ld %ld %ld %ld %ld %ld %ld\n",deb1,deb2,fin1,fin2,m->pdbatomtype[deb1].ATOM_residuesnumber,m->pdbatomtype[deb2].ATOM_residuesnumber,m->pdbatomtype[fin1].ATOM_residuesnumber,m->pdbatomtype[fin2].ATOM_residuesnumber);
	*/
	fout=fecrire(file_name);
	sprintf(file_name,"%s_%ld.pdb",m->name,under);
	fprintf(fout,"load \"%s\"\n",file_name);
	fprintf(fout,"select all\n");
	fprintf(fout,"color white\n");
	fprintf(fout,"cartoons\n");
	fprintf(fout,"background white\n");
	fprintf(fout,"select %ld-%ld\n",m->pdbatomtype[m->deb_residues[deb1]].ATOM_residuesnumber,m->pdbatomtype[m->deb_residues[deb2]].ATOM_residuesnumber);
	fprintf(fout,"color red\n");
	fprintf(fout,"select %ld-%ld\n",m->pdbatomtype[m->deb_residues[fin1]].ATOM_residuesnumber,m->pdbatomtype[m->deb_residues[fin2]].ATOM_residuesnumber);
	fprintf(fout,"color blue\n");
	fprintf(fout,"write %s_%ld.jpg\n",m->name,under);
	fprintf(fout,"quit\n");
	of(fout);
}

short int ReadDbS2(pdbfile *m,short int state);

char *Beta_Turn_Type[10]={"I","II","VIII","I'","II'","VIa1","VIb1","VIb2","IV","UNK"};

/********************************************************************************/
/*	beta:		short int BetaTurnPro[NB_MAX_RES][9];			*/
/*	gamma:		short int GammaTurnPro[NB_MAX_RES][2];			*/
/*	hairpin:	short int BetaHairpinPro[NB_MAX_RES];			*/
/********************************************************************************/
/*	gamma-turns:	0 : CLASSIC						*/
/*			1 : INVERSE						*/
/********************************************************************************/
/*	beta-turns : 0 : turn I							*/
/*		     1 : turn I'						*/
/*		     2 : turn II						*/
/*		     3 : turn II'						*/
/*		     4 : turn IV						*/
/*		     5 : turn VprotIa1						*/
/*		     6 : turn VIb1						*/
/*		     7 : turn VIb2						*/
/*		     8 : turn VIII						*/
/********************************************************************************/

/****************************************************************************/
/*	Promotif 06- Final check					    */
/****************************************************************************/

void checkreadpromotif(char *name,int hairp[2], int bt[2],int gt[2]){
	
		FILE *fout;
		
		fout=fopen("Results/stat_prom.txt","a+");
		fprintf(fout,"%s ",name);
		if((hairp[0]==hairp[1])&&(bt[0]==bt[1])&&(gt[0]==gt[1]))
		fprintf(fout,"OK ");
		else fprintf(fout,"NO ");
		fprintf(fout,"%3d %3d %3d %3d %3d %3d\n",hairp[0],hairp[1],bt[0],bt[1],gt[0],gt[1]);
		fclose(fout);

}

int test_cho(pdbfile *m, long *pst, char *AA, int lg){
	int test=0;
	int local_i;
	
	for(local_i=0;local_i<lg;local_i++)
		if(AA[local_i]!=m->Nam_residues[pst[local_i]-1])test++;
	return(test);
}

/****************************************************************************/
/*	Promotif 04bis- Beta turns reading				    */
/****************************************************************************/

void dispatch_bturns(pdbfile *m,char *buf, char AA[4],long posit[4],short int (*type),int (*chain_here)){
/*
         10        20        30        40
|         |         |         |         |
0123456789012345678901234567890123456789012345678901234567890
A   4 I    5 K    6 D    7 K IV   AP  -88.1 -42.3 -86.8  88.6  6.5 N -91.0-102.2    4
A   7 K    8 Q    9 L   10 T I    AA  -62.1 -18.5-108.2  13.1  6.0 Y -60.1 -55.9    7
A   9 L   10 T   11 G   12 L II   PG  -45.9 135.1  86.6 -21.4  5.8 Y -54.3 999.9    9
*/
	FILE *fout;
	long local_i;
	char smallbuf[5];
	char smallbuf4[5];	
	long deb;
	long local_posit[4];
	long local_posit_lasting;
	int test;
	
	(*type)=-1;
	
	/* chain number */
	
	if(buf[0]==' ')	(*chain_here)=0;
	else (*chain_here)=((int)buf[0]-(int)('A'));
	
	/* amino acid local_position */
	
	deb=1;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; 	local_posit[0]=atoi(smallbuf);
	deb=7;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit[1]=atoi(smallbuf);
	deb=14;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit[2]=atoi(smallbuf);
	deb=21;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit[3]=atoi(smallbuf);
	deb=80; for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit_lasting=atoi(smallbuf);

	/* amino acid  */

	AA[0]=buf[6];	AA[1]=buf[13];	AA[2]=buf[20]; AA[3]=buf[27];

	/* beta-turn type */

		
	for(local_i=0;local_i<4;local_i++){
		smallbuf4[local_i]=buf[29+local_i];
		if(smallbuf4[local_i]==((char)32))smallbuf4[local_i]='\0';
		}
	smallbuf4[local_i]='\0';
	
	/*printf("%d\n",(*chain_here));
	printf("AA => %c%c%c%c\n",AA[0],AA[1],AA[2],AA[3]);
	printf("local_posit => %ld %ld %ld %ld\n",local_posit[0],local_posit[1],local_posit[2],local_posit[3]);
	printf("smallbuf4 => %c%c%c%c\n",smallbuf4[0],smallbuf4[1],smallbuf4[2],smallbuf4[3]);
	*/
	
	/*recherche de la position veritable */
	for(local_i=0;local_i<4;local_i++)posit[local_i]=local_posit[local_i];
	
	test=test_cho(m,posit,AA,4);
		
	if(test>0){
		/*printf("AA     => %c%c%c%c\n",AA[0],AA[1],AA[2],AA[3]);
		printf("AAreel => %c%c%c%c\n",m->Nam_residues[posit[0]],m->Nam_residues[posit[1]-1],m->Nam_residues[posit[2]-1],m->Nam_residues[posit[3]-1]);
		*/
		for(local_i=0;local_i<4;local_i++) posit[local_i]=local_posit_lasting+local_i;
		
		/*printf("local_posit_lasting : %d\n",local_posit_lasting);*/
		/*
		printf("AA     => %c%c%c%c\n",AA[0],AA[1],AA[2],AA[3]);
		printf("AAreel => %c%c%c%c\n",m->Nam_residues[posit[0]-1],m->Nam_residues[posit[1]-1],m->Nam_residues[posit[2]-1],m->Nam_residues[posit[3]-1]);
		
		printf("%d\n",test=test_cho(m,posit,AA,4));
		*/
		test=test_cho(m,posit,AA,4);
		if(test_cho(m,posit,AA,4)>0){
			for(local_i=0;local_i<4;local_i++)posit[local_i]=local_posit_lasting+local_i-1;
		
			/*printf("AA     => %c%c%c%c\n",AA[0],AA[1],AA[2],AA[3]);
			printf("AAreel => %c%c%c%c\n",m->Nam_residues[posit[0]-1],m->Nam_residues[posit[1]-1],m->Nam_residues[posit[2]-1],m->Nam_residues[posit[3]-1]);
			
			printf("%d\n",test=test_cho(m,posit,AA,4));	*/
			test=test_cho(m,posit,AA,4);
		}
	}
	
	if(test>0)printf("some problems test_cho %d\n",test);
	
	for(local_i=0;local_i<9;local_i++){
		/*printf("|%s| |%s|%d\n",smallbuf4,Beta_Turn_Type[local_i],(int)(smallbuf4[3]));*/
		/*if(strncmp(smallbuf4,Beta_Turn_Type[local_i],strlen(Beta_Turn_Type[local_i]))==0){	pb*/
		if(strcmp(smallbuf4,Beta_Turn_Type[local_i])==0){
			/*printf("turns type %s\n",Beta_Turn_Type[local_i]);*/
			if((*type)<(0)){(*type)=local_i;}
			else {printf(" double assignation pour Beta turns %d et %ld\n",(*type),local_i);
			     (*type)=-1;
			     }
		}
	}
	
	if((*type)==(-1)){
		fout=fopen("Results/beta_turns.pb","a+"); fprintf(fout,"PB Bturns type:"); fprintf(fout,"%s",buf); fclose(fout);
		printf("PB Bturns type:"); printf("%s",buf);
	}

	/*printf("%ld [%c] %ld [%c] %ld [%c] %ld [%c] %d\n",local_posit[0],AA[0],local_posit[1],AA[1],local_posit[2],AA[2],local_posit[3],AA[3],(*type));*/
	
	/* check */
	
	for(local_i=0;local_i<3;local_i++){
		if((local_posit[local_i]+1)!=(local_posit[local_i]+1)){
		 fout=fopen("Results/beta_turns.pb","a+"); fprintf(fout,"PB Gturns continuity:"); fprintf(fout,"%s",buf); fclose(fout);
		 printf("PB Bturns continuity:"); printf("%s",buf);
	    	}
	}
	
	/*for(local_i=0;local_i<4;local_i++)posit[local_i]=local_posit[local_i];*/

}

/*************************/


/*if(ok!=0) {
			research_truepos(m,pos,AAl,chain_here);
			ok=0;
			for(p_04=0;p_04<4;p_04++){
				printf("B turns ( %ld %c %c %ld\n",p_04,AAl[p_04],m->Nam_residues[pos[p_04]-1],pos[p_04]-1);
				if(AAl[p_04]!=m->Nam_residues[pos[p_04]-1+(m->Pos_FirstRes[chain_here])])ok++;
			}
		}*/	
/*		
void research_truepos(pdbfile *m,long pos[4], char AA[4], int chain_number){
	long y21,i21,u;
	
	long true=-1;
	short int ok=0;
	y21=chain_number;
	
		for(i21=m->Pos_FirstRes[y21];i21<m->Pos_LastRes[y21];i21++){
		
				if(pos[0]-1==(m->pdbatomtype[m->deb_residues[i21]].ATOM_residuesnumber)) true=i21;
			if(true!=(-1))	for(u=0;u<4;u++) {
				ok=0;
				if(AA[u]!=m->Nam_residues[true+u])ok++;

				if(ok!=0)true=-1;
				else i21=m->Pos_LastRes[y21];
				}
			
		}
	for(u=0;u<4;u++) pos[u]=true+u;
	
}
*/

/****************************************************************************/
/*	Promotif 04- Beta turns reading				    */
/****************************************************************************/

void Read_Bturns(pdbfile *m,char *betafile, int bt[2]){
								/*************************/
	FILE *f_promotif;					/*         File          */
	FILE *f_follows;					/*         File          */
	char buffer[SIZE_Buffer];				/* buffer for gamma file */
	char AAl[4];						/*   the four positions  */
	long pos[4];						/*   the four positions  */
	long p_04;						/*     just to count     */
	int chain_here=-1;					/*     the chain number  */
	short int type=-1;					/* 9 types of beta-turns */
	short int ok=0;
								/*************************/

/* file example : pdb10mh.bturns
------------------------------------------------------------------------------------------------
Promotif output for protein :10mh
 Beta Turns
A   4 I    5 K    6 D    7 K IV   AP  -88.1 -42.3 -86.8  88.6  6.5 N -91.0-102.2    4
A   7 K    8 Q    9 L   10 T I    AA  -62.1 -18.5-108.2  13.1  6.0 Y -60.1 -55.9    7
A   9 L   10 T   11 G   12 L II   PG  -45.9 135.1  86.6 -21.4  5.8 Y -54.3 999.9    9
A  16 D   17 L   18 F   19 A IV   PL  -95.2 141.2  56.2  59.3  5.6 N -64.0 -53.9   16
A  19 A   20 G   21 L   22 G II'  EA   64.0-123.2 -83.3 -15.8  5.3 Y 999.9 -66.7   19
A  29 E   30 S   31 C   32 G I    AA  -59.1 -17.5-100.1  -2.6  4.9 Y  66.4 -59.2   29
A  65 N   66 E   67 K   68 T I    AA  -54.2 -14.9 -85.9  -1.0  5.8 Y  67.4 -58.0   65
A  66 E   67 K   68 T   69 I I    AA  -85.9  -1.0 -92.1 -23.6  5.8 N -58.0 -22.2   66
A  81 C   82 Q   83 A   84 F I    Aa  -44.1 -40.0 -84.7  21.5  5.2 Y -48.8 999.9   81
A  82 Q   83 A   84 F   85 S IV   aa  -84.7  21.5-144.2 -25.5  5.4 N 999.9 -60.7   82
A  85 S   86 I   87 S   88 G I    AA  -85.9  -2.5 -95.2 -18.7  5.7 N-168.6-118.1   85
A  95 D   96 S   97 R   98 G I    AA  -52.6 -17.5-105.9 -13.7  4.9 Y  63.0 -52.9   95
A  96 S   97 R   98 G   99 T IV   AA -105.9 -13.7 -93.4  19.4  6.3 N -52.9 999.9   96
A  97 R   98 G   99 T  100 L IV   AA  -93.4  19.4-115.4  -2.0  6.5 Y 999.9  70.4   97
A 209 R  210 K  211 D  212 L I    Aa  -89.3 -12.0 -95.1  22.8  5.9 Y -71.8  48.4  209
A 232 V  233 G  234 K  235 G II'  EA   66.1-122.9-106.3  -1.7  5.8 Y 999.9 -75.4  232
A 236 G  237 Q  238 G  239 E II   PG  -55.2 124.6  99.7   0.8  5.6 Y -67.0 999.9  236
A 237 Q  238 G  239 E  240 R IV   Ga   99.7   0.8-127.8   9.6  6.7 N 999.9 -41.3  237
A 243 S  244 T  245 R  246 G I    AA  -86.9   7.2 -98.2   9.4  6.1 Y  67.8-131.2  243
A 244 T  245 R  246 G  247 I IV   A   -98.2   9.4-126.6-138.4  6.9 N-131.2 999.9  244
A 252 S  253 A  254 Y  255 G IV   Aa  -94.8 -28.9-122.3  16.5  5.7 N 999.9 -66.9  252
A 257 G  258 I  259 F  260 A IV   Aa  -71.5 -32.5-107.6  43.4  4.9 Y-168.1 -53.7  257
A 259 F  260 A  261 K  262 T II   P   -38.6 136.0  68.3 -36.5  6.6 Y 999.9 -64.9  259
A 260 A  261 K  262 T  263 G IV    A   68.3 -36.5-100.3 -37.3  6.4 N -64.9  59.6  260
A 266 L  267 V  268 N  269 G IV   BL -112.5 125.7  39.0  42.9  6.5 N-170.9 -71.1  266
A 267 V  268 N  269 G  270 K I'   LG   39.0  42.9  99.1 -19.2  5.4 Y -71.1 999.9  267
A 286 P  287 D  288 S  289 Y I    AA  -60.3 -14.9 -87.7  -4.6  5.8 Y -64.3  51.2  286
------------------------------------------------------------------------------------------------
*/
	bt[0]=bt[1]=0;
	
	/*printf("ouverture de %s\n",betafile);*/
		
	f_promotif=fopen(betafile,"r");
	fgets(buffer,SIZE_Buffer,f_promotif);				/* Promotif output ...         */
	fgets(buffer,SIZE_Buffer,f_promotif);				/*  Beta Turns  ...            */
	
	while(fgets(buffer,SIZE_Buffer,f_promotif)!=NULL){		/* prend chaque ligne et compte */
		
		dispatch_bturns(m,buffer,AAl,pos,&type,&chain_here);
		
		ok=0;
		/*printf("%5d\t%s",bt[0],buffer);*/
		
		bt[0]++;
		for(p_04=0;p_04<4;p_04++){
			/*printf("01-> B turns ( %ld %c %c %ld\n",p_04,AAl[p_04],m->Nam_residues[pos[p_04]-1],pos[p_04]-1);*/
			if(AAl[p_04]!=m->Nam_residues[pos[p_04]-1])ok++;
		}
		
		if(ok==0){
			bt[1]++;
			/*printf("ok tout concorde\n--------------------\n");*/
			for(p_04=0;p_04<4;p_04++){
				m->BetaTurnPro[pos[p_04]-1][type]++;
				}
			}
		else 	{
			type=9;
			printf("Problem of Btuns concordance\n-------------------------\n");
			for(p_04=0;p_04<4;p_04++) m->BetaTurnPro[pos[p_04]-1][0]=-9;
			}
		f_follows=fSurecrire("Results/Rasta/btunrs.nxt");
		fprintf(f_follows,"%2d",bt[0]);
		for(p_04=0;p_04<4;p_04++)
			fprintf(f_follows,"%c",m->Nam_residues[pos[p_04]-1]);
			fprintf(f_follows," %4ld Beta-turns type %s\n",pos[0]-1,Beta_Turn_Type[type]);
		fclose(f_follows);	
		
	}
	fclose(f_promotif);
}

/****************************************************************************/
/*	Promotif 03bis- Gamma turns reading				    */
/****************************************************************************/

void dispatch_gturns(pdbfile *m, char *buf, char AA[3],long posit[3],short int *type,int *chain_here){
/*
         10        20        30        40
|         |         |         |         |
0123456789012345678901234567890123456789012345678901234567890
A 260 A  261 K  262 T CLASSIC    68.3 -36.5 5.9  -64.9  260
*/
	FILE *fout;
	long local_i;
	char smallbuf[5];
	long deb;
	long local_posit_lasting;
	long local_posit[3];
	int test;
	
	(*type)=-1;
	
	/* chain number */
	
	if(buf[0]==' ')	(*chain_here)=0;
	else (*chain_here)=((int)buf[0]-(int)('A'));
	
	/*printf("%d %c\n",(*chain_here),buf[0]);*/
	
	/* amino acid position */
	
	deb=1;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit[0]=atoi(smallbuf);
	deb=7;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit[1]=atoi(smallbuf);
	deb=14;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit[2]=atoi(smallbuf);
	deb=54; for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit_lasting=atoi(smallbuf);

	/*printf("local_posit_lasting : %d\n",local_posit_lasting);*/

	/* amino acid  */

	AA[0]=buf[6];	AA[1]=buf[13];	AA[2]=buf[20];


	for(local_i=0;local_i<3;local_i++)posit[local_i]=local_posit[local_i];
	
	test=test_cho(m,posit,AA,3);
		
	if(test>0){
		/*printf("AA     => %c%c%c%c\n",AA[0],AA[1],AA[2],AA[3]);
		printf("AAreel => %c%c%c%c\n",m->Nam_residues[posit[0]],m->Nam_residues[posit[1]-1],m->Nam_residues[posit[2]-1],m->Nam_residues[posit[3]-1]);
		*/
		for(local_i=0;local_i<3;local_i++) posit[local_i]=local_posit_lasting+local_i;
		
		/*
		printf("AA     => %c%c%c%c\n",AA[0],AA[1],AA[2],AA[3]);
		printf("AAreel => %c%c%c%c\n",m->Nam_residues[posit[0]-1],m->Nam_residues[posit[1]-1],m->Nam_residues[posit[2]-1],m->Nam_residues[posit[3]-1]);
		
		printf("%d\n",test=test_cho(m,posit,AA,3));
		*/
		test=test_cho(m,posit,AA,3);
		if(test_cho(m,posit,AA,3)>0){
			for(local_i=0;local_i<3;local_i++)posit[local_i]=local_posit_lasting+local_i-1;
		
			/*printf("AA     => %c%c%c%c\n",AA[0],AA[1],AA[2],AA[3]);
			printf("AAreel => %c%c%c%c\n",m->Nam_residues[posit[0]-1],m->Nam_residues[posit[1]-1],m->Nam_residues[posit[2]-1],m->Nam_residues[posit[3]-1]);
			
			printf("%d\n",test=test_cho(m,posit,AA,3));	*/
			test=test_cho(m,posit,AA,3);
		}
	}
	
	/*printf("test : %d\n",test);*/

	/* gamma-turn type */

	if(buf[22]=='C')(*type)=1;
	else {if(buf[22]=='I')(*type)=2;
	else {
	     fout=fopen("Results/gamma_turns.pb","a+"); fprintf(fout,"PB Gturns type:"); fprintf(fout,"%s",buf); fclose(fout);
	     printf("PB Gturns type:"); printf("%s",buf);
	     (*type)=3;
	     }
	}
	
	/*printf("%ld [%c] %ld [%c] %ld [%c] %d\n",posit[0],AA[0],posit[1],AA[1],posit[2],AA[2],(*type));*/
	
	/* check */
	
	for(local_i=0;local_i<2;local_i++){
		if((posit[local_i]+1)!=(posit[local_i]+1)){
		 fout=fopen("Results/gamma_turns.pb","a+"); fprintf(fout,"PB Gturns continuity:"); fprintf(fout,"%s",buf); fclose(fout);
		 printf("PB Gturns continuity:"); printf("%s",buf);
	    	}
	}

}

/****************************************************************************/
/*	Promotif 03- Gamma turns reading				    */
/****************************************************************************/

void Read_Gturns(pdbfile *m,char *gammafile, int gt[2]){
								/*************************/
	FILE *f0;						/*         File          */
	FILE *f_follows;	
	char buffer[SIZE_Buffer];				/* buffer for gamma file */
	char AAl[3];						/* the three little pigs */
	long pos[3];						/* the house of the l.p. */
	long p_03;						/*     just to count     */
	int chain_here=-1;					/*     the chain number  */
	short int type=-1;					/*   classic or inverse  */
	short int ok=0;
									/*************************/

	
/* file example : pdb10mh.gturns
------------------------------------------------------------------------------------------------
Promotif output for protein :10mh
 Gamma Turns
A   5 K    6 D    7 K INVERSE P -86.8  88.6 5.9 -102.2    5
A   6 D    7 K    8 Q INVERSE P -73.0  80.2 5.6  -60.2    6
A 159 I  160 P  161 Q INVERSE P -86.1  67.9 5.8   35.1  159
A 161 Q  162 K  163 R INVERSE P -78.0  68.5 5.7  172.8  161
A 223 T  224 P  225 K INVERSE P -87.5  62.7 5.5   35.9  223
A 260 A  261 K  262 T CLASSIC    68.3 -36.5 5.9  -64.9  260
------------------------------------------------------------------------------------------------
*/
	
	gt[0]=gt[1]=0;
	
	f0=fopen(gammafile,"r");
	fgets(buffer,SIZE_Buffer,f0);				/* Promotif output ...         */
	/*printf("read ligne 1 : %s",buffer);*/
	fgets(buffer,SIZE_Buffer,f0);				/*  Gamma Turns  ...            */
	/*printf("read ligne 2 : %s",buffer);*/
	while(fgets(buffer,SIZE_Buffer,f0)!=NULL){		/* prend chaque ligne et compte */
		dispatch_gturns(m,buffer,AAl,pos,&type,&chain_here);
		gt[0]++;
		ok=0;
		for(p_03=0;p_03<3;p_03++){
			/*printf("%ld %c %c %ld [chain %d]\n",p_03,AAl[p_03],m->Nam_residues[pos[p_03]-1],pos[p_03]-1,chain_here);*/
			if(AAl[p_03]!=m->Nam_residues[pos[p_03]-1])ok++;
		}
		if(ok==0){
			gt[1]++;
			/*printf("ok tout concorde\n");*/
			for(p_03=0;p_03<3;p_03++){
				m->GammaTurnPro[pos[p_03]-1][type]++;
				}
			}
		else 	{
			m->GammaTurnPro[pos[p_03]-1][0]=9;
			printf("PB Gturns non concordance\n");
			}
		f_follows=fSurecrire("Results/Rasta/gtunrs.nxt");
		fprintf(f_follows,"%2d",gt[0]);
		for(p_03=0;p_03<3;p_03++)
			fprintf(f_follows,"%c",m->Nam_residues[pos[p_03]-1]);
			fprintf(f_follows," %4ld Gamma-turns type %d\n",pos[0]-1,type);
		fclose(f_follows);
	}
}


void dispatch_hairpin(pdbfile *m,char *buf, char AA[200],long posit[400],int *length_hairpin,short int *chain, int lg[3]){

	long local_i;
	char smallbuf[5];
	long deb;
	long local_posit_lasting[2];
	long local_posit[400];
	int lgAA=0;
	int test;
	
/*
         10        20        30        40	 50	
|         |         |         |         |         |         |
0123456789012345678901234567890123456789012345678901234567890
  1   2    14     19     25     28    3:  5      6  4                  RLKIYK        DTEGY                                                                                                                         YTIG                           PAAGP                                                                                                                          6  4  2  2  0  0  0  0  0  0  0  0 1 1 1 1 2 0 0 0 0 0 0 0  2  2  1   14   28
  2   3    25     28     31     34    3:  3      4  4                    YTIG        IG                                                                                                                            HLLT                           BL                                                                                                                             4  4  2  1  0  0  0  0  0  0  0  0 0 1 0 0 0 0 0 0 0 0 0 0  2  1  1   25   34
  5   6 A 148  A 153  A 164  A 171    8: 10      6  8                  HAKVLN        ALDYGIPQKR                                                                                                                    ERIYMICF                       AAAaGBPBPB                                                                                                                     6  6  4  4  2  2  0  0  0  0  0  0 1 1 1 0 0 0 0 0 0 0 0 0  2  2  1  148  171
  7   8 A 213  A 214  A 228  A 231   13: 15      2  4                      VM        TNQEIEQTTPKTV                                                                                                                 RLGI                           ABBPPABPBPBPB                                                                                                                  2  4  0  0  0  0  0  0  0  0  0  0 0 0 0 0 0 0 0 0 0 0 0 0  2  4  1  213  231
  8   9 A 228  A 231  A 240  A 243    6:  8      4  4                    RLGI        VGKGGQGE                                                                                                                      RIYS                           BEAGPPGa                                                                                                                       2  2  0  0  0  0  0  0  0  0  0  0 1 1 1 0 0 0 0 0 0 0 0 0  2  2  1  228  243
 10  11 A 264  A 267  A 270  A 272    2:  2  IP  4  3                    GYLV        NG                                                                                                                            KTR                            LG                                                                                                                             3  3  1  1  0  0  0  0  0  0  0  0 0 0 0 0 0 0 0 0 0 0 0 0  0  0  0  264  272
------------------------------------------------------------------------------------------------
*/

	(*length_hairpin)=0;
	
	if(buf[8]==' ')	(*chain)=0;
	else (*chain)=((int)buf[8]-(int)('A'));
	
	/* amino acid position */
	
	deb=9;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit[0]=atoi(smallbuf);
	deb=16;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit[1]=atoi(smallbuf);
	deb=23;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit[2]=atoi(smallbuf);
	deb=30; for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit[3]=atoi(smallbuf);
	
	/* real positions */
	
	deb=436; for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit_lasting[0]=atoi(smallbuf);
	deb=441; for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit_lasting[1]=atoi(smallbuf);

	/*printf("%ld %ld\n",local_posit_lasting[0],local_posit_lasting[1]);*/

	/* amino acid  */

	deb=55;	for(local_i=deb;local_i<240;local_i++)
			if((buf[local_i]>='A')&&(buf[local_i]<'Z'))
					AA[lgAA++]=buf[local_i];
	
	/*for(local_i=0;local_i<lgAA;local_i++)printf("%ld %c\n",local_i,AA[local_i]);*/
	/*	printf("%ld %ld %d\n",local_posit[3]-local_posit[0],local_posit_lasting[1]-local_posit_lasting[0],lgAA);		
	for(local_i=0;local_i<lgAA;local_i++)printf("%c|",AA[local_i]);printf("\n");
	printf("AA     => %c%c%c%c\n",AA[0],AA[1],AA[2],AA[3]);*/
	
	lg[0]=local_posit[1]-local_posit[0];
	lg[1]=local_posit[2]-local_posit[1]-1;
	lg[2]=lgAA;
	
	for(local_i=0;local_i<lgAA;local_i++) posit[local_i]=local_posit[0]+local_i;
	
	test=test_cho(m,posit,AA,lgAA);
		
	if(test>0){
		/*printf("AA     => %c%c%c%c\n",AA[0],AA[1],AA[2],AA[3]);
		printf("AAreel => %c%c%c%c\n",m->Nam_residues[posit[0]-1],m->Nam_residues[posit[1]-1],m->Nam_residues[posit[2]-1],m->Nam_residues[posit[3]-1]);
		*/
		for(local_i=0;local_i<lgAA;local_i++) posit[local_i]=local_posit_lasting[0]+local_i;
		
		
		/*printf("AA     => %c%c%c%c\n",AA[0],AA[1],AA[2],AA[3]);
		printf("AAreel => %c%c%c%c\n",m->Nam_residues[posit[0]-1],m->Nam_residues[posit[1]-1],m->Nam_residues[posit[2]-1],m->Nam_residues[posit[3]-1]);
		*/
		/*printf("%d\n",test=test_cho(m,posit,AA,lgAA));*/
		
		test=test_cho(m,posit,AA,lgAA);
		if(test_cho(m,posit,AA,lgAA)>0){
			for(local_i=0;local_i<lgAA;local_i++) posit[local_i]=local_posit_lasting[0]+local_i-1;
		
			/*printf("AA     => %c%c%c%c\n",AA[0],AA[1],AA[2],AA[3]);
			printf("AAreel => %c%c%c%c\n",m->Nam_residues[posit[0]-1],m->Nam_residues[posit[1]-1],m->Nam_residues[posit[2]-1],m->Nam_residues[posit[3]-1]);
			
			printf("%d\n",test=test_cho(m,posit,AA,3));	*/
			test=test_cho(m,posit,AA,3);
		}
	}
	
	if(test>0) printf("PB hairpin %d\n",test);
	
}

/****************************************************************************/
/*	Promotif 02bis- Hairpin reading					    */
/****************************************************************************/

void olddispatch_hairpin(char *buf, char AA[200],long posit[4],int *length_hairpin,short int *chain){

	FILE *fout;
	long local_i;
	char smallbuf[5];
	long deb;
	short int count=0;
	short int color=0;
	long local_posit_lasting[2];
	long local_posit[4];
	int lgAA=0;

/*
         10        20        30        40	 50	
|         |         |         |         |         |         |
0123456789012345678901234567890123456789012345678901234567890
  1   2    14     19     25     28    3:  5      6  4                  RLKIYK        DTEGY                                                                                                                         YTIG                           PAAGP                                                                                                                          6  4  2  2  0  0  0  0  0  0  0  0 1 1 1 1 2 0 0 0 0 0 0 0  2  2  1   14   28
  2   3    25     28     31     34    3:  3      4  4                    YTIG        IG                                                                                                                            HLLT                           BL                                                                                                                             4  4  2  1  0  0  0  0  0  0  0  0 0 1 0 0 0 0 0 0 0 0 0 0  2  1  1   25   34
  5   6 A 148  A 153  A 164  A 171    8: 10      6  8                  HAKVLN        ALDYGIPQKR                                                                                                                    ERIYMICF                       AAAaGBPBPB                                                                                                                     6  6  4  4  2  2  0  0  0  0  0  0 1 1 1 0 0 0 0 0 0 0 0 0  2  2  1  148  171
  7   8 A 213  A 214  A 228  A 231   13: 15      2  4                      VM        TNQEIEQTTPKTV                                                                                                                 RLGI                           ABBPPABPBPBPB                                                                                                                  2  4  0  0  0  0  0  0  0  0  0  0 0 0 0 0 0 0 0 0 0 0 0 0  2  4  1  213  231
  8   9 A 228  A 231  A 240  A 243    6:  8      4  4                    RLGI        VGKGGQGE                                                                                                                      RIYS                           BEAGPPGa                                                                                                                       2  2  0  0  0  0  0  0  0  0  0  0 1 1 1 0 0 0 0 0 0 0 0 0  2  2  1  228  243
 10  11 A 264  A 267  A 270  A 272    2:  2  IP  4  3                    GYLV        NG                                                                                                                            KTR                            LG                                                                                                                             3  3  1  1  0  0  0  0  0  0  0  0 0 0 0 0 0 0 0 0 0 0 0 0  0  0  0  264  272
------------------------------------------------------------------------------------------------
*/

	(*length_hairpin)=0;
	
	if(buf[8]==' ')	(*chain)=0;
	else (*chain)=((int)buf[8]-(int)('A'));
	
	/* amino acid position */
	
	deb=9;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit[0]=atoi(smallbuf);
	deb=16;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit[1]=atoi(smallbuf);
	deb=23;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit[2]=atoi(smallbuf);
	deb=30; for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit[3]=atoi(smallbuf);
	deb=436; for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit_lasting[0]=atoi(smallbuf);
	deb=441; for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit_lasting[1]=atoi(smallbuf);

	/*printf("%ld %ld\n",local_posit_lasting[0],local_posit_lasting[1]);*/

	/* amino acid  */

	deb=55;	for(local_i=deb;local_i<240;local_i++)
			if((buf[local_i]>='A')&&(buf[local_i]<'Z'))
					AA[lgAA++]=buf[local_i];
	
	for(local_i=0;local_i<lgAA;local_i++)printf("%ld %c\n",local_i,AA[local_i]);
			


	/*printf("%ld %ld %ld %ld\n",posit[0],posit[1],posit[2],posit[3]);*/

	local_i=53;
	while(count<6){	
		if(buf[local_i]==((char)(32))){
			if(color==1){
				color--;
				count++;
				}
		/*printf("0-|%c| color : %d count : %d\n",buf[local_i],color,count);*/
		}
		else{
		if((buf[local_i]<('Z'))&&(buf[local_i]>=('A'))){
			/*printf("%c",buf[local_i]);*/
			if(color==0){
				color++;
				count++;
				}
			/*printf("1-|%c| color : %d count : %d\n",buf[local_i],color,count);*/
			AA[(*length_hairpin)]=buf[local_i];
			(*length_hairpin)++;
			}
			else{
			printf("Problem-|%c| color : %d count : %d [%ld]\n",buf[local_i],color,count,local_i);
			}	
		}	
	
		local_i++;
		if(local_i>500){
			count=50;
			 fout=fopen("Results/beta_hairpin.pb","a+"); fprintf(fout,"PB hairpins continuity:"); fprintf(fout,"%s",buf); fclose(fout);
		 	 printf("PB beta hairpins:"); printf("%s",buf);
	    		}
	}
	
	if((posit[3]-posit[0]+1)!=(*length_hairpin))
	printf("Problem in hairpin length in sequence : %d | in beta-loop-beta : %ld\n",(*length_hairpin),posit[3]-posit[0]+1);
	/*	else printf("hairpin length in sequence : %d | in beta-loop-beta :%ld\n",(*length_hairpin),posit[3]-posit[0]+1);	*/
}

/****************************************************************************/
/*	Promotif 02- Hairpin reading					    */
/****************************************************************************/

void Read_hairpin(pdbfile *m,char *hairpinfile, int hairp[2]){
								/**********************************/
	FILE *f0;						/*		file		  */
	FILE *f_follows;						/*		file		  */	
	char buffer[4*SIZE_Buffer];				/* hpin file could be longggggggg */
	char AAl[200];						/*    the sequence of the haipin  */
	int length_hairpin;					/*     the length of the haipin   */
	long pos[400];						/*    position of the beta-sheet  */
	long p_02,s_02;						/*           just to count        */
	short int chain_here=-1;				/*          the chain number      */
	short int ok=0;						/*		test		  */
	int lg[3];
								/**********************************/

/* file example : 119l.hpin and 10mh.hpin
------------------------------------------------------------------------------------------------
Promotif output for protein :119l
  1   2    14     19     25     28    3:  5      6  4                  RLKIYK        DTEGY                                                                                                                         YTIG                           PAAGP                                                                                                                          6  4  2  2  0  0  0  0  0  0  0  0 1 1 1 1 2 0 0 0 0 0 0 0  2  2  1   14   28
  2   3    25     28     31     34    3:  3      4  4                    YTIG        IG                                                                                                                            HLLT                           BL                                                                                                                             4  4  2  1  0  0  0  0  0  0  0  0 0 1 0 0 0 0 0 0 0 0 0 0  2  1  1   25   34
------------------------------------------------------------------------------------------------
Promotif output for protein :10mh
  5   6 A 148  A 153  A 164  A 171    8: 10      6  8                  HAKVLN        ALDYGIPQKR                                                                                                                    ERIYMICF                       AAAaGBPBPB                                                                                                                     6  6  4  4  2  2  0  0  0  0  0  0 1 1 1 0 0 0 0 0 0 0 0 0  2  2  1  148  171
  7   8 A 213  A 214  A 228  A 231   13: 15      2  4                      VM        TNQEIEQTTPKTV                                                                                                                 RLGI                           ABBPPABPBPBPB                                                                                                                  2  4  0  0  0  0  0  0  0  0  0  0 0 0 0 0 0 0 0 0 0 0 0 0  2  4  1  213  231
  8   9 A 228  A 231  A 240  A 243    6:  8      4  4                    RLGI        VGKGGQGE                                                                                                                      RIYS                           BEAGPPGa                                                                                                                       2  2  0  0  0  0  0  0  0  0  0  0 1 1 1 0 0 0 0 0 0 0 0 0  2  2  1  228  243
 10  11 A 264  A 267  A 270  A 272    2:  2  IP  4  3                    GYLV        NG                                                                                                                            KTR                            LG                                                                                                                             3  3  1  1  0  0  0  0  0  0  0  0 0 0 0 0 0 0 0 0 0 0 0 0  0  0  0  264  272
------------------------------------------------------------------------------------------------
*/

	/* m->Pos_FirstRes[chain_here] */

	hairp[0]=hairp[1]=0;

	f0=fopen(hairpinfile,"r");
	fgets(buffer,4*SIZE_Buffer,f0);				/* first ligne */
	while(fgets(buffer,4*SIZE_Buffer,f0)!=NULL){		/* prend chaque ligne et compte */
		dispatch_hairpin(m,buffer,AAl,pos,&length_hairpin,&chain_here,lg);
		hairp[0]++;
		ok=0;
		for(p_02=0;p_02<lg[2];p_02++){
			if(AAl[p_02]!=(m->Nam_residues[pos[0]+p_02-1]))ok++;
		}
		if(ok==0){
			hairp[1]++;
			/*printf("ok tout concorde\n");*/
			/*s_02=0;						
			for(p_02=pos[s_02];p_02<pos[s_02+1]+1;p_02++)
				m->BetaHairpinPro[p_02-1+(m->Pos_FirstRes[chain_here])]+=(s_02+1);
			s_02=1;						
			for(p_02=pos[s_02]+1;p_02<pos[s_02+1];p_02++)
				m->BetaHairpinPro[p_02-1+(m->Pos_FirstRes[chain_here])]+=(s_02+1);
			s_02=2;						
			for(p_02=pos[s_02];p_02<pos[s_02+1]+1;p_02++)
				m->BetaHairpinPro[p_02-1+(m->Pos_FirstRes[chain_here])]+=(s_02+1);
			*/	
			s_02=1;						/* first beta */
			for(p_02=pos[0];p_02<=pos[0]+lg[0];p_02++)
				m->BetaHairpinPro[p_02-1]+=(s_02);
			s_02=2;						/*    loop     */
			for(p_02=pos[0]+lg[0]+1;p_02<=pos[0]+lg[0]+lg[1];p_02++)
				m->BetaHairpinPro[p_02-1]+=(s_02);
			s_02=3;						/* second beta */
			for(p_02=pos[0]+lg[0]+lg[1]+1;p_02<pos[0]+lg[2];p_02++)
				m->BetaHairpinPro[p_02-1]+=(s_02);
				
			/*printf("%d %d %d\n",lg[0],lg[1],lg[2]);
			printf("%ld %ld\n",pos[0],pos[0]+lg[0]);
			printf("%ld %ld\n",pos[0]+lg[0]+1,pos[0]+lg[0]+lg[1]);
			printf("%ld %ld\n",pos[0]+lg[0]+lg[1]+1,pos[0]+lg[2]);
			*/
			}
		else 	printf("PB hairpin concordance\n");
		f_follows=fSurecrire("Results/Rasta/hpins.nxt");
		fprintf(f_follows,"%2d\n",hairp[0]);
		fprintf(f_follows,"\tfirst beta \n\t");
		for(p_02=pos[0];p_02<=pos[0]+lg[0];p_02++)
			fprintf(f_follows,"%c",m->Nam_residues[p_02-1]);
		fprintf(f_follows,"\n\tloops \n\t");		
		for(p_02=pos[0]+lg[0]+1;p_02<=pos[0]+lg[0]+lg[1];p_02++)
			fprintf(f_follows,"%c",m->Nam_residues[p_02-1]);
		fprintf(f_follows,"\n\tsecond beta \n\t");		
		for(p_02=pos[0]+lg[0]+lg[1]+1;p_02<pos[0]+lg[2];p_02++)
			fprintf(f_follows,"%c",m->Nam_residues[p_02-1]);
		
		fprintf(f_follows,"\n");
		fclose(f_follows);
	}
}


void Read_psiloops(pdbfile *m,char *loopinfile, int psi[2]){

	FILE *f0;						/*		file		  */
	FILE *f_follows;					/*		file		  */	
	char buf[SIZE_Buffer];
	char smallbuf[4];
	long local_posit[6];
	long local_i,s_02,p_02;
	int deb;
	
	int lg[3];
	
	psi[0]=psi[1]=0;
	
	if((f0=fopen(loopinfile,"r"))!=0){
       		printf("file %s is present\n",loopinfile);
		while(fgets(buf,SIZE_Buffer,f0)!=NULL){	
		
		psi[0]++;
		deb=1;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit[0]=atoi(smallbuf);
		deb=8;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit[1]=atoi(smallbuf);
		deb=17;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit[2]=atoi(smallbuf);		
		deb=24;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit[3]=atoi(smallbuf);
		
		deb=30;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit[4]=atoi(smallbuf);
		deb=35;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; local_posit[5]=atoi(smallbuf);

		lg[0]=local_posit[1]-local_posit[0];
		lg[1]=local_posit[2]-local_posit[1]-1;
		lg[2]=local_posit[3]-local_posit[0]+1;
	
		if((local_posit[5]-local_posit[4])==(local_posit[3]-local_posit[0]))psi[1]++;
		
		printf("PSI-LOOPS :%ld %ld\n",local_posit[5]-local_posit[4],local_posit[3]-local_posit[0]);
	
		s_02=1;									/* first beta */
		for(p_02=local_posit[4];p_02<=local_posit[4]+lg[0];p_02++)
			m->PsiLoopPro[p_02-1]+=(s_02);
		
		s_02=2;									/*    psi- loop     */
		for(p_02=local_posit[4]+lg[0]+1;p_02<=local_posit[4]+lg[0]+lg[1];p_02++)
			m->PsiLoopPro[p_02-1]+=(s_02);
		
		s_02=3;									/* second beta */
		for(p_02=local_posit[4]+lg[0]+lg[1]+1;p_02<local_posit[4]+lg[2];p_02++)
			m->PsiLoopPro[p_02-1]+=(s_02);
			
		f_follows=fSurecrire("Results/Rasta/psiloops.nxt");
		fprintf(f_follows,"%s\t%2d\n",m->name,psi[0]);
		fprintf(f_follows,"\tfirst beta \n\t");
		for(p_02=local_posit[4];p_02<=local_posit[4]+lg[0];p_02++)
			fprintf(f_follows,"%c",m->Nam_residues[p_02-1]);fprintf(f_follows,"\t");
		
		for(p_02=local_posit[4];p_02<=local_posit[4]+lg[0];p_02++) fprintf(f_follows,"%c",BPtrans(m->Assign_PB[p_02-1]));
			
		fprintf(f_follows,"\n\tpsi-loops \n\t");		
		for(p_02=local_posit[4]+lg[0]+1;p_02<=local_posit[4]+lg[0]+lg[1];p_02++)
			fprintf(f_follows,"%c",m->Nam_residues[p_02-1]);fprintf(f_follows,"\t");
		
		for(p_02=local_posit[4]+lg[0]+1;p_02<=local_posit[4]+lg[0]+lg[1];p_02++)fprintf(f_follows,"%c",BPtrans(m->Assign_PB[p_02-1]));
			
		fprintf(f_follows,"\n\tsecond beta \n\t");		
		for(p_02=local_posit[4]+lg[0]+lg[1]+1;p_02<local_posit[4]+lg[2];p_02++)
			fprintf(f_follows,"%c",m->Nam_residues[p_02-1]);fprintf(f_follows,"\t");
			
		for(p_02=local_posit[4]+lg[0]+lg[1]+1;p_02<local_posit[4]+lg[2];p_02++)fprintf(f_follows,"%c",BPtrans(m->Assign_PB[p_02-1]));
		
		fprintf(f_follows,"\n");
		fclose(f_follows);			
		if(CutPsiLoops=='T'){
			WritePartPdb(m,local_posit[4]-1,local_posit[4]+lg[2],psi[0]);
			WriteRasmolPsiLoops(m,local_posit[4]-1,local_posit[4]+lg[0]+2,local_posit[4]+lg[0]+lg[1],local_posit[4]+lg[2]+1,psi[0]);
			}
		}
		
	fclose(f0);
	} 
	
	else printf("file %s not present\n",loopinfile);


}

/**************************************/

void dispatch_bbulges(pdbfile *m,char *buf, char AA[4],long posit[4],short int (*type),int (*chain_here), int (*number_bulg), int (*lg_bul)){
/*
         10        20        30        40        50        60        70        80        80        90       100       110       120       130       140
|         |         |         |         |         |         |         |         |         |         |         |         |         |         |         |         |
A C A  61  I  -119.8  142.0 A  57  L	-88.5  -12.8 A  58  G	 90.4  171.6	       -999.9 -999.9	       -999.9 -999.9	58   54   55
A S A  99  R  -105.7  -16.8 A  84  Y  -120.7	82.7 A  85  P	-54.5  -31.7 A  86  E	-88.9	-2.4 A  87  G	 78.6  154.5	96   81   82   83   84
A C B  61  I  -120.4  135.8 B  57  L	-88.5  -12.9 B  58  G	 97.5  171.1	       -999.9 -999.9	       -999.9 -999.9   202  198  199
A S B  99  R  -105.5  -13.8 B  84  Y  -124.4	85.7 B  85  P	-56.2  -35.9 B  86  E	-85.5	-2.6 B  87  G	 77.8  153.4   240  225  226  227  228
A C C  61  I  -119.0  139.3 C  57  L  -112.1	 1.0 C  58  G	 93.4  167.2	       -999.9 -999.9	       -999.9 -999.9   345  341  342
*/
/*	FILE *fout;*/
	long local_i;
	char smallbuf[5];
/*	char smallbuf4[5];	*/
	long deb;
	long local_posit[5];
	long local_posit_lasting[5];
	int test;
	
	(*type)=-1;
	(*number_bulg)++;
	
	/* chain number */
	
	if(buf[4]==' ')	(*chain_here)=0;
	else (*chain_here)=((int)buf[0]-(int)('A'));
	
	/*printf("chain %d %c %c\n",(*chain_here),buf[0],buf[2]);*/
	
	/* amino acid local_position */
	
	deb=5;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i]; 	local_posit[0]=atoi(smallbuf);
	deb=29;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit[1]=atoi(smallbuf);
	deb=53;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit[2]=atoi(smallbuf);
	deb=77;	for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit[3]=atoi(smallbuf);
	deb=101;for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit[4]=atoi(smallbuf);
	
	deb=124; for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit_lasting[0]=atoi(smallbuf);
	deb=129; for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit_lasting[1]=atoi(smallbuf);
	deb=134; for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit_lasting[2]=atoi(smallbuf);
	deb=139; for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit_lasting[3]=atoi(smallbuf);
	deb=144; for(local_i=deb;local_i<deb+5;local_i++) smallbuf[local_i-deb]=buf[local_i];	local_posit_lasting[4]=atoi(smallbuf);


	/* amino acid  */

	AA[0]=buf[11];
	AA[1]=buf[35];	
	AA[2]=buf[59]; 
	AA[3]=buf[83];
	AA[4]=buf[107];	

	if(AA[4]==' ')(*lg_bul)=4;
	if(AA[3]==' ')(*lg_bul)=3;
	
	/*for(local_i=0;local_i<(*lg_bul);local_i++)
		printf("%c %ld %ld\n",AA[local_i],local_posit_lasting[local_i],local_posit[local_i]);*/
	
	/* beta-bulge type */

	test=0;(*type)=-1;
	while(test==0){
		(*type)++;
		if((buf[0]==short_betabul_name[(*type)][0])&&(buf[2]==short_betabul_name[(*type)][2]))test=1;
		if((*type)>10)test=1;
		}
	(*type)++; /* pour demarrer de un et non de zero */	
	
	/* beta-bulge position */
	
	for(local_i=0;local_i<(*lg_bul);local_i++) posit[local_i]=local_posit[local_i];
	
	test=test_cho(m,posit,AA,(*lg_bul));
	
	if(test>0){
		/*printf("AA     => %c%c%c%c\n",AA[0],AA[1],AA[2],AA[3]);
		printf("AAreel => %c%c%c%c\n",m->Nam_residues[posit[0]],m->Nam_residues[posit[1]-1],m->Nam_residues[posit[2]-1],m->Nam_residues[posit[3]-1]);*/
		
		for(local_i=0;local_i<(*lg_bul);local_i++) posit[local_i]=local_posit_lasting[local_i];
		
		/*printf("AA     => %c%c%c%c\n",AA[0],AA[1],AA[2],AA[3]);
		printf("AAreel => %c%c%c%c\n",m->Nam_residues[posit[0]-1],m->Nam_residues[posit[1]-1],m->Nam_residues[posit[2]-1],m->Nam_residues[posit[3]-1]);*/
		
		/*printf("%d\n",test=test_cho(m,posit,AA,(*lg_bul)));*/
		
		test=test_cho(m,posit,AA,(*lg_bul));
		if(test_cho(m,posit,AA,(*lg_bul))>0){
			for(local_i=0;local_i<3;local_i++) posit[local_i]=local_posit_lasting[local_i]-1;
			test=test_cho(m,posit,AA,3);
		}
	}
	
	/*printf("chain %d %c %c => %d\n",(*chain_here),buf[0],buf[2],(*type));*/

}


/****************************************************************************/
/*	Promotif 05- Beta bulges reading				    */
/****************************************************************************/

void Read_betabulge(pdbfile *m,char *betafile, int bb[2]){
								/*************************/
	FILE *f_promotif;					/*         File          */
	FILE *f_follows;					/*         File          */
	char buffer[SIZE_Buffer];				/* buffer for bbulge file*/
	char AAl[5];						/*   the four positions  */
	long pos[5];						/*   the four positions  */
	long p_04;						/*     just to count     */
	int chain_here=-1;					/*     the chain number  */
	short int type=-1;					/*10 types of beta-bulges*/
	short int ok=0;						/*			 */
	int number_bulg=0;
	int lg_b=-1;
								/*************************/

	bb[0]=bb[1]=0;
	
	printf("ouverture de %s\n",betafile);
		
	f_promotif=fopen(betafile,"r");
	
	while(fgets(buffer,SIZE_Buffer,f_promotif)!=NULL){		/* prend chaque ligne et compte */
		
		dispatch_bbulges(m,buffer,AAl,pos,&type,&chain_here,&number_bulg,&lg_b);
		
		ok=0;
		/*printf("%5d [%2d]\t%s",bb[0],number_bulg,buffer);*/
		
		bb[0]++;
		for(p_04=0;p_04<lg_b;p_04++){
			/*printf("01-> B turns ( %ld %c %c %ld\n",p_04,AAl[p_04],m->Nam_residues[pos[p_04]-1],pos[p_04]-1);*/
			if(AAl[p_04]!=m->Nam_residues[pos[p_04]-1])ok++;
		}
		
		if(ok==0){
			bb[1]++;
			/*printf("ok tout concorde\n--------------------\n");*/
			}
		else 	{
			type=11;
			printf("Problem of beta - bulges concordance\n-------------------------\n");
			f_follows=fSurecrire("Results/pb-bbulges.tnx");
			fprintf(f_follows,"%s\t%2d\t",m->name,bb[1]);
			for(p_04=0;p_04<lg_b;p_04++)
				fprintf(f_follows,"%c",m->Nam_residues[pos[p_04]-1]);
				fprintf(f_follows," %4ld Beta-bulges type %d\n",pos[0]-1,type);
			fclose(f_follows);
			}
			
		for(p_04=0;p_04<lg_b;p_04++) {
			m->BetaBulPro[pos[p_04]-1]=type;	
			m->BetaBulProX[pos[p_04]-1]=number_bulg;
			}
		
		f_follows=fSurecrire("Results/Rasta/bbulges.nxt");
		fprintf(f_follows,"%2d\t",bb[0]);
		for(p_04=0;p_04<lg_b;p_04++)
			fprintf(f_follows,"%c",m->Nam_residues[pos[p_04]-1]);
			fprintf(f_follows," %4ld Beta-bulges type %d\n",pos[0]-1,type);
		fclose(f_follows);	
		
	}
	fclose(f_promotif);
}


/****************************************************************************/
/*	Promotif 01- Main part						    */
/****************************************************************************/

void Promotif_Read(pdbfile *m){

	int p01;				/*          to count        */
	int last=0;				/*          to count        */
	char sys[SIZE_Buffer];			/* buffer to execute system */
	char use[SIZE_Buffer];			/*  to search PDB filename  */
	char pdb[SIZE_Buffer];			/*  to search PDB filename  */
	int hairp[2];				/*	  hairpins          */
	int bt[2];				/*	beta-turns 	    */
	int gt[2];				/*	gamma-turns	    */
	/*int pl[2];*/				/*	psi-loops	    */
	int bb[2];				/*	beta-bulges	    */
	
	if(ReadDbS2(m,8)!=0){
	/************************************************/	
	/* Promotif step 01 : run baby run the software */
	/************************************************/
		
	sprintf(sys,"/home/glenan/logiciels/bin/promotif2.scr %s",nom_fichier);
	system(sys);

	/*************************************************/	
	/* Promotif step 02 : search for the right files */
	/*************************************************/

	clean(use,SIZE_Buffer);

	for(p01=0;p01<strlen(nom_fichier)-1;p01++)
		if(nom_fichier[p01]=='/') last=p01+1;

	for(p01=last;p01<strlen(nom_fichier)-4;p01++)
		use[p01-(last)]=nom_fichier[p01];

	/*printf("PROMOTIF 3- last+1 %d\n",last+1);
	printf("PROMOTIF 4- \n%s %d %d|%s|\n",nom_fichier,strlen(nom_fichier),last,use);
	*/
	sprintf(pdb,"%s",use);


	/*****************************************/	
	/* Promotif step 03 : read hairpin files */
	/*****************************************/

	/*printf("Promotif step 03 : read hairpin files\n");*/

	strcat(use,".hpin");	

	Read_hairpin(m,use,hairp);

	/********************************************/	
	/* Promotif step 04 : read gamma turn files */
	/********************************************/

	/*printf("Promotif step 04 : read gamma turn files\n");*/

	sprintf(use,"%s",pdb);
	strcat(use,".gturns");	

	/*printf("Promotif step 04 : Read_Gturns : %s, %d[%d\n",use,gt[0],gt[1]);*/

	Read_Gturns(m,use,gt);

	/********************************************/	
	/* Promotif step 04 : read gamma turn files */
	/********************************************/

	/*printf("Promotif step 04 : read gamma turn files\n");*/

	sprintf(use,"%s",pdb);
	strcat(use,".bturns");	

	Read_Bturns(m,use,bt);
	
	/*******************************************/	
	/* Promotif step 05 : read psi-loops files */
	/*******************************************/

	printf("Promotif step 05 : read psi-loops files [%s] => Warning NOT DONE\n",pdb);

	sprintf(use,"%s",pdb);
	strcat(use,".psi");	

	/*Read_psiloops(m,use,pl);*/


	/*********************************************/	
	/* Promotif step 06 : read beta-bulges files */
	/*********************************************/

	/*printf("Promotif step 06 : read beta-bulges files[%s]\n",pdb);*/
	
	sprintf(use,"%s",pdb);
	strcat(use,".blg");	

	Read_betabulge(m,use,bb);


	/******************************************/	
	/* Promotif step 07 : clean all the files */
	/******************************************/

	/*printf("Promotif step 07 : clean all the files\n");*/
	
	/*clean(sys,SIZE_Buffer);
	sprintf(sys,"cp %s.blg temp/",pdb);
	system(sys);*/
	
	clean(sys,SIZE_Buffer);
	sprintf(sys,"rm -rf %s.*",pdb);
	system(sys);
	printf("%s\n",sys);

	/*******************************/	
	/* Promotif step 06 : check up */
	/*******************************/

	/*printf("Promotif step 08 : check up\n");*/

	sprintf(use,"%s",pdb);
	checkreadpromotif(use,hairp,bt,gt);
	}
	
}
