/* ------------------------------------------------------------------------ */
/*  Copyright by Manfred J.Sippl             25/01/93                       */
/* ------------------------------------------------------------------------ */
/* ------------------------------------------------------------------------ */
/*			  superimpose example driver                        */
/* ------------------------------------------------------------------------ */

/* ------------------------------------------------------------------------
 Code may be used free of charge for non profit purposes.
 Reports of applications or extensions are very wellcome.
 Please report problems to
 Manfred J.Sippl
 Center for Applied Molecular Engineering /
 University of Salzburg
 Salzburger TechnoZ
 Jakob Haringer Str.1 / A-5020 Salzburg / Austria
 Tel.: (043) 662-8044-5797
 Fax.: (043) 662-454889
 INTERNET: SIPPL@DSB835.EDVZ.SBG.AC.AT
 ------------------------------------------------------------------------ */

/*
=========================================================================
IMPLEMENTATION NOTES:

The module contains three functions which calculate rms-errors of
optimal superimpositions:

(1) spp_superpose_rot()
    Function returns the square of the rms-error. The coordinates of
    X remain unchanged. Y is optimally superimposed on X.
    The coordinates of X and Y are not translated to their geometric centers,
    i.e. no minimization with respect to translation is performed.
(2) spp_superpose_full()
    Function returns the square of the rms-error. The coordinates of
    X remain unchanged. Y is optimally superimposed on X.
(3) spp_superperr_rot()
    Function returns the square of the rms-error. The coordinataes of X
    and Y remain unchanged. The coordinates of X and Y are not translated
    to their geometric centers, i.e. no minimization with respect to
    translation is performed.
(4) spp_superperr_full()
    Function returns the square of the rms-error. The coordinates of
    X and Y remain unchanged.

Note on failure of convergence:
If the algorithm fails to converge the iteration is restarted by rotating
the coordinates of X; this sometimes helps.
If the algorithm fails again the iteration is restarted by rotating X
to the eigensystem defined by the tensor of X; this sometimes helps too.
if all fails the algorithm terminates and returns the rms-error using
the current result. In this case the rms-error and superimposition are
unreliable, although the superimposition may still be useful.
- if you find a better way please let me know -

You may retry by changing the maximum number of iterations performed.

Note that this version of the algorithm contains a few additions and
corrections with respect to Sippl & Stegbuchner (1991).

==========================================================================
*/

#include <stdlib.h>
#include <stdio.h>
#include <math.h>

#include "coordfun.h"
#include "superimp.h"

#include <malloc.h>

# include "../HEADER/options.h" /*ADB add*/

void mainpassSippl(double *Xa, double *Ya, double *Za, double *Xb, double *Yb, double *Zb, long longeur_frag)
{
  CARRAY *o1=0, *o2=0;
  COORDS *c1, *c2;
  double  squared_rms;
 
  o1 = coo_read_carray(o1,Xa,Ya,Za,longeur_frag);
  o2 = coo_read_carray(o2,Xb,Yb,Zb,longeur_frag);
  
/*  if (o1 == 0) exit(1);*/
  spp_set_precision(1.0e-8);   /* very high precision */

/* ------------------------------------------------------------------------ */
/* Example 1								    */
/* ------------------------------------------------------------------------ */
  c1 = o1->coo;
  c2 = o2->coo;
/*  coo_print_coords(c1,(int)longeur_frag);
  coo_print_coords(c2,(int)longeur_frag);  
*/ 
/*
  squared_rms = spp_superperr_full(c1,c2,(int)longeur_frag);
  printf("rms spp_superperr_full : %15.8f\n",sqrt(squared_rms));
 */  
/*  coo_print_coords(c1,(int)longeur_frag);
  coo_print_coords(c2,(int)longeur_frag);  */

/* la bonne fonction qui permet d'avoir une superposition de Y sur X optimale */
  
  squared_rms = spp_superpose_full(c1,c2,(int)longeur_frag);
  
/*  printf("rms spp_superpose_full : %15.8f\n",sqrt(squared_rms));*/
  
/*  coo_print_coords(c1,(int)longeur_frag);
  coo_print_coords(c2,(int)longeur_frag);  */
  
  
/* 
	redcalle tout sur le centre 
 squared_rms = spp_superperr_fullAdB(c1,c2,(int)longeur_frag);
  printf("rms spp_superperr_fullAdB : %15.8f\n",sqrt(squared_rms));
  
  coo_print_coords(c1,(int)longeur_frag);
  coo_print_coords(c2,(int)longeur_frag);  
 */ 
  
  
  /*
	  fonction fait que plante semble-t-il:
  	  -------------------------------------
  squared_rms = spp_superpose_rot(c1,c2,(int)longeur_frag);
  printf("rms spp_superpose_rot : %15.8f\n",sqrt(squared_rms));
  coo_print_coords(c1,(int)longeur_frag);
  coo_print_coords(c2,(int)longeur_frag);
  */
  
  o1 = coo_free_carray(o1);
  o2 = coo_free_carray(o2);
 
}

void Sippl(double *Xa, double *Ya, double *Za, double *Xb, double *Yb, double *Zb, long longeur_frag)
{
  CARRAY *o1=0, *o2=0;
  COORDS *c1, *c2;
  double  squared_rms;
 
  o1 = coo_read_carray(o1,Xa,Ya,Za,longeur_frag);
  o2 = coo_read_carray(o2,Xb,Yb,Zb,longeur_frag);
  
/*  if (o1 == 0) exit(1);*/
  spp_set_precision(1.0e-8);   /* very high precision */

/* ------------------------------------------------------------------------ */
/* Example 1								    */
/* ------------------------------------------------------------------------ */
  c1 = o1->coo;
  c2 = o2->coo;

  if(Werboze=='T'){
  	printf("Sippl step 01 (mol.1)\n");
  	coo_print_coords(c1,(int)longeur_frag);
  	printf("Sippl step 01 (mol.2)\n");	
	coo_print_coords(c2,(int)longeur_frag);  
      }
 
/*
  squared_rms = spp_superperr_full(c1,c2,(int)longeur_frag);
  printf("rms spp_superperr_full : %15.8f\n",sqrt(squared_rms));
 */  
/*  coo_print_coords(c1,(int)longeur_frag);
  coo_print_coords(c2,(int)longeur_frag);  */

/* la bonne fonction qui permet d'avoir une superposition de Y sur X optimale */
  
  squared_rms = spp_superpose_full(c1,c2,(int)longeur_frag);
  
  if(Werboze=='T') printf("rms spp_superpose_full : %15.8f\n",sqrt(squared_rms));
  
/*  coo_print_coords(c1,(int)longeur_frag);
  coo_print_coords(c2,(int)longeur_frag);  */
  
  
/* 
	redcalle tout sur le centre */
/* squared_rms = spp_superperr_fullAdB(c1,c2,(int)longeur_frag);
  printf("rms spp_superperr_fullAdB : %15.8f\n",sqrt(squared_rms));*/
  /*
  coo_print_coords(c1,(int)longeur_frag);
  coo_print_coords(c2,(int)longeur_frag);  
 */ 
  
  
  /*
	  fonction fait que plante semble-t-il:
  	  -------------------------------------
  squared_rms = spp_superpose_rot(c1,c2,(int)longeur_frag);
  printf("rms spp_superpose_rot : %15.8f\n",sqrt(squared_rms));
  */
   if(Werboze=='T'){
  	printf("Sippl step 02 (mol.1)\n");
	coo_print_coords(c1,(int)longeur_frag);
	printf("Sippl step 02 (mol.2)\n");
	coo_print_coords(c2,(int)longeur_frag);
  	}
  comeback(c2,Xb,Yb,Zb,(int)longeur_frag);
  
  o1 = coo_free_carray(o1);
  o2 = coo_free_carray(o2);
 
}
